* Master Do File - Analysis
* Pakistan Property Tax Project

/*********************************************************

	OVERVIEW
	This step compiles the cleaned data into datasets that
	will be used in analysis.
	
	The second half of the do file generates tables
	that appear in the paper.
	
***********************************************************/

clear all
set more off

**************************************
* Set-up

// Set up the directory global. This will be shared across do files. Just add your 
// directory below to get set up.

// cap cd *FILL IN HERE*
cap cd "C:/Users/Kunal/Dropbox (CID)/TFR/"
cap cd "/Users/ismailkhan/Dropbox (CID)/TFR/"

global PAKTAX_ANALYSIS = "`c(pwd)'"
global PAPER_ANALYSIS = "`c(pwd)'//Analysis/"
global DATA = "`c(pwd)'/Data/"
global PAKTAX_RANDOMIZATION = "`c(pwd)'/Data/Randomization/"
global TABLE_OUTPUT = "`c(pwd)'//Analysis/Tables/"
global RI_OUTPUT = "`c(pwd)'//Analysis/RI/"
cap cd "${PAPER_ANALYSIS}"

***************************************

******************************** 
****		HR 
********************************

* We use HR data to determine the extent to which treatment was actually implemented
* (i.e. treatmennt no longer applied if a treated staff was transferred out)

** Implementation across quarters for Phase II (year 1 of treatment)
	// INPUTS: Data/Randomization/Phase II/Randomization/110810 7861 Subreatment Randomization - Copy
	//		   Data/Randomization/Phase II/Randomization/110809 Randomization Output - Additional Circles 999 - Copy
	// OUTPUTS: Analysis/Coded Data/Phase II Balloted Circle HR Change Tracking.dta
	do "Do Files/Coding/121105 Phase II Implementation Tracking.do"

** Implementation across quarters for Phase III (year 2 of treatment)
	// INPUTS: Data/Randomization/ETO & AETO/120707 ETO Randomization Output 6465 - New List - Randomization Circles.dta
	//		   Data/Cleaned Data/Administrative Data/Punjab Compiled - Quarterly.dta
	//		   Data/Raw Data/Current HR Confirmation/Master Treated Staff (long).dta
	//	       Data/Cleaned Data/Randomization/130506 Cleaned Phase III Randomization.dta
	// OUTPUTS: Analysis/Coded Data/Phase III ETO Clusters and Implementation.dta
do "Do Files/Coding/130903 ETO Clusters and Phase III Implementation.do"


** Balance Stats for HR; number of staff at randomization, etc.
	// INPUTS:  Data/Raw Data/Current HR Confirmation/110709 Final Director Verified Master Punjab Current HR Data.csv
	// OUTPUTS: Analysis/Coded Data/HR/Staff Stats.dta
do "Do Files/Coding/130517 Balance Stats on Staff.do"


******************************** 
****		ADMIN TAX DATA
********************************

** Clustering by robust partition
	// INPUTS: Data/Cleaned Data/Administrative Data/Crosswalk/Keys/*
	// OUTPUTS: Analysis/Coded Data/Circle Clusters.dta
do "Do Files/Coding/Circle Clusters.do"

** Treatment Variables
	// INPUTS: Analysis/Coded Data/Phase II Balloted Circle HR Change Tracking.dta
	//		   Analysis/Coded Data/Phase III ETO Clusters and Implementation.dta
	//		   Data/Cleaned Data/Randomization/130506 Cleaned Phase III Randomization.dta
	//		   Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Randomization/*
	// OUTPUTS: Analysis/Coded Data/treatment_vars.dta
do "Do Files/Coding/Admin Treatment Variables"
	
** Compile everything above together with crosswalked admin data
	// INPUTS:  Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Present - Analysis/2011_q4_crosswalk.dta
	//		    Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Present - Analysis/2012_q1_crosswalk.dta
	//		    Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Randomization/*
	//		    Analysis/Coded Data/treatment_vars.dta
	//		    Analysis/Coded Data/Circle Clusters.dta
	//		    Analysis/Coded Data/Staff Stats.dta
	//		    Analysis/Coded Data/Benchmarks/121221 Phase II Benchmarks - Full Sample - RANDOMIZATION CIRCLES.dta
	// OUTPUTS: Analysis/Coded Data/Phase III Analysis.dta
do "Do Files/Coding/Analysis Coding.do"


******************************** 
****		SURVEY DATA
********************************	
	
** Clustering by robust partition in terms of survey circle IDs
	// INPUTS: Data/Cleaned Data/Administrative Data/Crosswalk/Keys/*
	// OUTPUTS: Coded Data/Survey Circle Clusters.dta
do "Do Files/Coding/survey/Survey Circle Clusters.do"

** Crosswalk treatment variables to Q2 FY 2013 circles (which is what the survey data is defined in terms of)
do "Do Files/Coding/survey/Survey Treatment Variables.do"

** Compile it all together
do "Do Files/Coding/survey/Survey Analysis Coding.do"

******************************** 
****		INSPECTOR SURVEY
********************************

** Treatment variables in terms of Q4 2013 circles
do "Do Files/Coding/Inspector Treatment Variables.do"

** Compile it all together
	// INPUTS: Data/Cleaned Data/Administrative Data/Crosswalk/Keys/*
	// OUTPUTS: Analysis/Coded Data/Inspector Circle Clusters
do "Do Files/Coding/Inspector Circle Clusters.do"


************************************************
****		RANDOMIZATION INFERENCE
************************************************

* Randomization Inference
	// For the supervisor treatment and balance table we need to use randomized inference p-values
	// instead of clustered standard errors, because in simulations we've checked
	// and found that in small samples the regular standard errors over-reject.

* CAREFUL: This takes a long time to run.
* Number of iterations for analysis: 1000.

global iter 5
do "Do Files/Coding/150525 rerandomization.do"


**************************************************************************************
**************************************************************************************
**************************************************************************************
**************************************************************************************
**************************************************************************************


***************************************
* Paper Tables

*******************
* MAIN TABLES
*******************

	// Standard treatment is to put the INFO treatment in the controls.
	// However, we have an online appendix version where we take it out.

	// Tables generated here will have a _infocontrol suffix if from the info_in_controls folder

	* 1 Experimental Design
	do "Do Files/Paper/treat_implement_table.do"

	* 2 Summary Stats
	do "Do Files/Paper/summary_stats.do"

	* 3 Main Admin Outcomes
	do "Do Files/Paper/info_in_controls/revenue.do"

	* 4 Main Non-Revenue Outcomes
	do "Do Files/Paper/info_in_controls/nonrevenue.do"

	* 5 Impacts on Number of Properties
	do "Do Files/Paper/info_in_controls/number_properties.do"

	* 6 Impacts on Tax and Corruption, by Reassessed
	do "Do Files/Paper/info_in_controls/who_pays_more_main.do"

	* 7 Impacts on Satisfaction and Accuracy, by Reassessed
	do "Do Files/Paper/info_in_controls/sec9_nonrevenue.do"
	
	* 8 Selection Effects in Reassessment
	do "Do Files/Paper/info_in_controls/who_gets_reassessed_main.do"

	* 9 ROI
	do "Do Files/Paper/ROI.do"

*******************
* APPENDIX TABLES
*******************

	* Spillovers
	do "Do Files/Coding/Clean Tax Circle Boundaries.do" // Creates proximity.dta, which is an input into spillovers.do
	do "Do Files/Paper/spillovers.do"
	
	* Balance
	*do "Do Files/Paper/RI/130706 Randomization Balance_RI.do" // Calculate RI p-values first. CAREFUL: This takes a very long time to run.
	do "Do Files/Paper/randomization_balance.do"

	* Satisfaction and Corruption Correlations
	do "Do Files/Paper/satisfaction_correlations.do"

	* Satisfaction with Government
	do "Do Files/Paper/info_in_controls/satisfaction.do"

	* Margins of Impact
	do "Do Files/Paper/info_in_controls/margins_main.do"
	
	* Bribe Payment, Extensive vs. Intensive Margin
	do "Do Files/Paper/extension/bribe_intensive.do"
	
	* Inspector Effort
	do "Do Files/Paper/info_in_controls/inspector_effort.do"
	
	* Probability of Transfer
	do "Do Files/Paper/extensions/transfers_long.do"
	
	* Inspector Knowledge
	do "Do Files/Paper/inspector_knowledge.do"
	
	* Inspector Beliefs
	do "Do Files/Paper/inspector_beliefs.do"
	
	* Mechanisms beyond price effects
	// Need to run both of the following files as well, but these take a long time so be careful before calling
	* do "Do Files/Paper/info_in_controls/income_effect_standarderror.do"
	* do "Do Files/Paper/RI/130920 Revenue_Supervisors_RI.do" // Calculate RI p-values first. 
	do "Do Files/Paper/info_in_controls/additional_channels.do"
	
	* Supervisor Interactions
	* RI p values already generated in "Do Files/Paper/RI/130920 Revenue_Supervisors_RI.do"
	do "Do Files/Paper/info_in_controls/supervisors_interaction.do"

	* Inspector Monitoring
	do "Do Files/Paper/info_in_controls/inspector_monitoring.do"
	
	* Reassessed New vs. Newly Constructed New
	do "Do Files/Paper/extensions/new_vs_randomnew.do"

	* Heterogeneity in Reassessment Rate by Tax Density
	* 	do "Do Files/Paper/extensions/reassess_rate_bootstrap.do"  // This requires 1000 iterations, will take time
	do "Do Files/Paper/extensions/reassessment_rate_heterogeneity.do"
	
	
* Extensions to Main Tables and Robustness Checks
* -----------------------------------------------------

	* Summary Stats
	do "Do Files/Paper/summary_stats_full.do"

	* Revenue, Dropping Circles with Boundary Changes
	do "Do Files/Paper/info_in_controls/revenue_nocrosswalk.do"
	
	* Revenue, Reduced Form
	do "Do Files/Paper/info_in_controls/revenue_reducedform.do"

	* Non-Revenue, Reduced Form
	do "Do Files/Paper/info_in_controls/nonrevenue_reducedform.do"
	
	* Non-Revenue, controlling for Objective Property Chars.
	do "Do Files/Paper/info_in_controls/nonrevenue_propcontrol.do"

	* Non-Revenue, with Elec Controls
	do "Do Files/Paper/info_in_controls/nonrevenue_eleccontrol.do"

	* Non-Revenue, Ordered Probit
	do "Do Files/Paper/info_in_controls/nonrevenue_orderedprobit.do"
	
* Versions of main tables with subtreatments
* -----------------------------------------------------

	* Margins by subtreatment
	do "Do Files/Paper/info_in_controls/margins_subs.do"

	* Impacts on Tax and Corruption, by Section 9 and subtreatment
	do "Do Files/Paper/info_in_controls/who_pays_more_subs.do"

	* Impacts on Satisfaction and Accuracy, by Section 9 and subtreatment
	do "Do Files/Paper/info_in_controls/sec9_nonrevenue_subs.do"
	

* Version of all tables with info out of controls
* --------------------------------------------------------

// Tables generated here will have a _infoout suffix

	* Main Admin Outcomes
	do "Do Files/Paper/info_out_controls/revenue.do"

	* Main Non-Revenue Outcomes
	do "Do Files/Paper/info_out_controls/nonrevenue.do"

	* Main Margins of Impact
	do "Do Files/Paper/info_out_controls/margins_main.do"

	* Selection Effects in Reassessment
	do "Do Files/Paper/info_out_controls/who_gets_reassessed_main.do"

	* Impacts on Tax and Corruption, by Section 9
	do "Do Files/Paper/info_out_controls/who_pays_more_main.do"

	* Impacts on Tax and Corruption, by Reassessed
	do "Do Files/Paper/info_out_controls/sec9_nonrevenue.do"

	
* Dropping Rev+ circles
* --------------------------------------------------------

	* Main Admin Outcomes
	do "Do Files/Paper/droprevplus/revenue.do"

	* Main Non-Revenue Outcomes
	do "Do Files/Paper/droprevplus/nonrevenue.do"

	* Main Margins of Impact
	do "Do Files/Paper/droprevplus/margins_main.do"

	* Selection Effects in Reassessment
	do "Do Files/Paper/droprevplus/who_gets_reassessed_main.do"

	* Impacts on Tax and Corruption, by Section 9
	do "Do Files/Paper/droprevplus/who_pays_more_main.do"

	* Impacts on Tax and Corruption, by Reassessed
	do "Do Files/Paper/droprevplus/sec9_nonrevenue.do"

	* Additional Channels
	* do "Do Files/Paper/droprevplus/income_effect_standarderror.do"
	* do "Do Files/Paper/RI/140801 Revenue_Supervisors_DropRevPlus_RI.do" // Calculate RI p-values first. CAREFUL: This takes a very long time to run.
	do "Do Files/Paper/info_in_controls/additional_channels.do"


* Controlling for Balance Check properties
* --------------------------------------------------------

	* Revenue, Balance Control
	do "Do Files/Paper/info_in_controls/revenue_balancecontrol.do"
	
	* Non-Revenue, Balance Control
	do "Do Files/Paper/info_in_controls/nonrevenue_balancecontrol.do"

* Dropping GPS Sampled Point
* --------------------------------------------------------

	* Selection Effects in Reassessment, Dropping GPS-sampled point
	do "Do Files/Paper/info_in_controls/who_gets_reassessed_main_dropfirstpoint.do"

	* Selection Effects in Reassessment, Dropping GPS-sampled point
	do "Do Files/Paper/info_in_controls/who_pays_more_main_dropfirstpoint.do"
	
* Dropping Renters
* --------------------------------------------------------

	* Non-revenue outcomes, Dropping Renters
	do "Do Files/Paper/info_in_controls/nonrevenue_droprenters.do"
	
	* Selection Effects in Reassessment, Dropping Renters
	do "Do Files/Paper/info_in_controls/who_gets_reassessed_main_droprenter.do"
	
	* Selection Effects in Reassessment, Dropping Renters
	do "Do Files/Paper/info_in_controls/who_pays_more_main_droprenter.do"
	
* Version of all tables with both phases
* --------------------------------------------------------

	* Main Non-Revenue Outcomes
	do "Do Files/Paper/info_in_controls/nonrevenue_bothphase.do"
	
	* Impacts on Bribes and Tax
	do "Do Files/Paper/info_in_controls/who_pays_more_main_bothphase.do"
	
	do "Do Files/Paper/info_in_controls/who_pays_more_subs_bothphase.do"
	
	* Impacts on Tax and Corruption, by Reassessed
	do "Do Files/Paper/info_in_controls/sec9_nonrevenue_bothphase.do"
	
	do "Do Files/Paper/info_in_controls/sec9_nonrevenue_subs_bothphase.do"
