/******************************
	Admin Analysis Data
	
	Compiles 1) crosswalked circle level data; 2) treatment variables; 3) circle clusters; and 4) balance stats on staff into
	a single dataset that will be the main data used for admin level analysis.
	
	Output: Phase III Analysis Data
	
	Kunal Mangal
	27 May 2014
*******************************/

clear all
set more off

cap cd "${PAPER_ANALYSIS}"

**************
* 1. Set up tax data
**************

forval q = 1/4 {
	use "${DATA}/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Present - Analysis/2012_q1_crosswalk.dta", clear
	keep if inlist(circle_id, 809301, 809302)
	keep circle_id q`q'_2011_gross_dem* q`q'_2011_net_dem* q`q'_2011_recov_tot* q`q'_2010_gross_dem* q`q'_2010_net_dem* q`q'_2010_recov_tot*

	collapse (sum) q`q'_2011_gross_dem* q`q'_2011_net_dem* q`q'_2011_recov_tot* q`q'_2010_gross_dem* q`q'_2010_net_dem* q`q'_2010_recov_tot*
	gen circle_id = 809300

	tempfile overwrite
	save `overwrite'

	use "${DATA}/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Present - Analysis/2011_q4_crosswalk.dta", clear
	keep if inlist(circle_id, 402300, 403902)
	keep circle_id q`q'_2011_gross_dem* q`q'_2011_net_dem* q`q'_2011_recov_tot* q`q'_2010_gross_dem* q`q'_2010_net_dem* q`q'_2010_recov_tot*

	tempfile overwrite2
	save `overwrite2'

	insheet using "${DATA}/Raw Data/Administrative Data/120904 Crosswalk to Randomization_All.csv", comma clear
	keep rand_circle_id
	drop if missing(rand_circle_id)
	rename rand_circle_id circle_id
	duplicates drop

	merge 1:1 circle_id using "${DATA}/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Present - Analysis/2012_q1_crosswalk.dta", keepusing(q`q'_2011_* q`q'_2010_*)
	drop if _merge == 2
	drop _merge 

	merge 1:1 circle_id using "${DATA}/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Present - Analysis/2011_q4_crosswalk.dta", keepusing(q`q'_2011_* q`q'_2010_*) update
	drop if _merge == 2
	drop _merge 

	merge 1:1 circle_id using `overwrite', update
	drop _merge

	merge 1:1 circle_id using `overwrite2', update replace
	drop _merge

	rename q`q'_2011* base*

	foreach var in gross_dem net_dem recov_tot {
		replace base_`var'_a = round(base_`var'_a)
		replace base_`var'_c = round(base_`var'_c)
		gen base_`var'_t = base_`var'_a + base_`var'_c
	}

	foreach var in gross_dem net_dem recov_tot {
		replace q`q'_2010_`var'_a = round(q`q'_2010_`var'_a)
		replace q`q'_2010_`var'_c = round(q`q'_2010_`var'_c)
		gen q`q'_2010_`var'_t = q`q'_2010_`var'_a + q`q'_2010_`var'_c
	}
	
	foreach var in gross_dem net_dem recov_tot {
		foreach x in t c a {
			gen base_ln_`var'_`x' = log(base_`var'_`x')
		}
	}

	if `q' == 1 {
		gen qtr = `q'
		tempfile base
		save `base'
	}
	else {
		gen qtr = `q'
		append using `base'
		save `base', replace
	}
}

forval y = 2012/2013 {
	forval q = 1/4 {
		use "${DATA}/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Randomization/`y'_q`q'.dta", clear
		gen fyear = `y'
		gen qtr = `q'
		
		if `y' == 2012 & `q' == 1 {
			tempfile rand
			save `rand'
		}
		else {
			append using `rand'
			save `rand', replace
		}
	}
}

use `rand', clear
merge m:1 circle_id qtr using `base'
assert _merge == 3
drop _merge

foreach x in c a t {
	gen recoveryrate_`x' = recov_tot_`x'/net_dem_`x'
	gen nonexemptrate_`x' = net_dem_`x'/gross_dem_`x'
}

foreach var in gross_dem net_dem recov_tot recoveryrate nonexemptrate {
	foreach x in t c a {
		gen ln_`var'_`x' = log(`var'_`x')
	}
}

* RANDOMIZATION & IMPLEMENTATION
merge 1:1 circle_id fyear qtr using "Coded Data/treatment_vars"
assert _m==3
drop _m

merge 1:1 circle_id fyear qtr using "Coded Data/Circle Clusters"
assert _m==3
drop _m

order circle_id fyear qtr gross* ln_gross* net* ln_net* recov* ln_recov* recoveryrate* ln_recoveryrate* nonexempt* ln_nonexempt* base*, first

rename div division_id
tab division_id, gen(divdum)
drop divdum1

gen base_ln_nonexemptrate_t = log(base_net_dem_t / base_gross_dem_t)
gen base_ln_recoveryrate_t = log(base_recov_tot_t / base_net_dem_t)

gen base_ln_growthrate_t = .
forval q = 1/4 {
	replace base_ln_growthrate_t = log(base_recov_tot_t / q`q'_2010_recov_tot_t) if qtr == `q'
}

drop q?_2010_*

* HR
merge m:1 circle_id using "Coded Data/Staff Stats.dta"
assert _m!=1
count if _m==2
assert `r(N)'==6	// 5 Lahore C circles new in fy2011 & alipurchat situation
keep if _m==3
drop _m

* BENCHMARKS
preserve
	u "Coded Data/Benchmarks/121221 Phase II Benchmarks - Full Sample - RANDOMIZATION CIRCLES.dta", clear
	keep circle_id bench_q*
	forv q = 1/4 {
		g bench`q' = bench_q`q'_c+bench_q`q'_a
		drop bench_q`q'*
		}
	reshape long bench, i(circle_id) j(qtr)
	g fyear=2012
	tempfile bench
	sa `bench'
restore

merge 1:1 circle_id fyear qtr using `bench'
count if _m!=3 & fyear==2012
assert `r(N)'==4	// this is 409600 being annoying
drop if _m==2
assert _m==3 if fyear==2012
drop _m



compress
saveold "Coded Data/Phase III Analysis Data.dta", replace
