* Treatment Variables for Inspector Circles

* Two sets of treatment variables -- implement (endogenous -- inspector postings) and select (exogenous -- randomization results)
* Implement is based on which treatment staff are present in their assigned circles as of Q4 FY 2013
* Select is in terms of randomization circles. To make in terms of Q4 FY 2013 circles, take a simple average of
* select across the randomization circles that merge into a Q4 FY 2013 circle

* Globals used here are defined in Master Pakistan Tax Analysis.do

version 12
clear all
pr drop _all
cap log close
set more off
set mem 300m
*set mat 10000

cap cd "${PAPER_ANALYSIS}"

********************************************************************

* Locals for last day of quarter
local day1 = 19266
local day2 = 19358
local day3 = 19448
local day4 = 19539

insheet using "${DATA}/Raw Data/Administrative Data/120904 Crosswalk to Randomization_All.csv", comma clear
forv q = 1/1 {
	preserve
		keep rand_circle_id q`q'_2013_circle_id
		drop if q`q'_2013_circle_id==.
		duplicates drop
		tempfile q`q'
		sa `q`q''
	restore
	}


* IMPORTANT NOTE: Information circles here are given their true implementation coefficient, which is later renamed to INFO_impl in Phase III Final Coding.
* In that do-file, the _impl_c variable is replaced to 0, because _impl_c is for truly treatment circles; informations are considered control.

* INFORMATION CIRCLES
u "${DATA}/Cleaned Data/Randomization/130506 Cleaned Phase III Randomization.dta", clear
keep if fyear==2013
keep circle_id infotreat2
keep if infotreat2==1
ren infotreat2 information
ren circle_id rand_circle_id
merge 1:m rand_circle_id using `q1'	// assuming things stay constant, can do only to this quarter
assert _m!=1
keep if _m==3
drop _m
keep q1_2013_circle_id information
ren q1_2013_circle_id circle_id
tempfile info
sa `info'


// Inspector survey circles are in terms of Q4 FY 2013 circles
local q 4

	* GET REGULAR CIRCLE TREATS; MERGING INFORMATION
	u "${DATA}/Raw Data/Current HR Confirmation/Master Treated Staff (long).dta", clear
	merge m:1 circle_id using `info'
	assert _m!=2	// won't be the case if there are merge/split issues; would need to deal with it.
	replace information = 0 if information==.
	drop _m
	replace treat=1 if _indate==19181 & information==1	// they are "treated" in information if still there from beginning
	replace subtreatment=4 if information==1	// all circles in information
	keep if subtreatment!=.
	g stafftype = substr(pos,1,3)

	* RATIOS
	g pos_type = substr(position,1,(length(position)-2))
	g pos_ratio = .4 if pos_type=="ins"
	replace pos_ratio = .3 if inlist(pos_type,"cons","clk")
	
	* GEN IMPLEMENT: SUM THIS FOR NUMERATOR
	g implement = pos_ratio
	replace implement = 0 if treat!=1	// remember we've adjusted the treat variable for info people.

	rename position pos
	
	* KEEP RIGHT PEOPLE
	keep if _indate<=`day`q'' & `day`q''<=_outdate
		
	* FIX IT IF WE'RE CATCHING A CHANGE-OVER DAY
	bys circle_id pos: g temp = _N
	drop if `day`q''==_outdate & temp>1
	bys circle_id pos: g temp2 = _N
	assert temp2==1 | treat!=1	// either we've dealt with it or we don't care
	drop temp*
	
	* STAFF DENOMINATOR
	preserve
		drop if inlist(pos,"aeto","eto")
		bys circle_id pos_type: g staffnum = _N
		g addon1 = pos_ratio if staffnum==2
		bys circle_id: egen addon2 = total(addon1)
		g denominator = 1+(addon2/2)
		ta denominator
		assert denominator!=.
		keep circle_id denominator
		duplicates drop
		tempfile denom
		sa `denom'
	restore
	merge m:1 circle_id using `denom'
	assert _m==3 if subtreatment!=.
	drop _m

	* RATIO
	bys circle_id: egen implement_num = total(implement)
	g _impl_q`q' = (implement_num/denominator)
	assert _impl_q`q'!=.
	
	rename _impl_q4 _impl_c_xw

	gen REV_impl_xw = _impl_c_xw if subtreatment == 1
	gen REVPLS_impl_xw = _impl_c_xw if subtreatment == 2
	gen CFW_impl_xw = _impl_c_xw if subtreatment == 3
	gen INFO_impl_xw = _impl_c_xw if information == 1
	
	* FIX INFORMATION IMPLEMENTATION COEFFICIENT
	replace _impl_c = 0 if information==1
	
	keep circle_id *_impl*
	duplicates drop 
	
	* To handle 901210 where we have both REV and CFW staff
	collapse (sum) _impl_c_xw REV_impl_xw REVPLS_impl_xw CFW_impl_xw INFO_impl_xw, by(circle_id)
		
	tempfile impl
	save `impl'

** CREATE CROSSWALK: SURVEY (Q4 2013) CIRCLES -> RANDOMIZATION CIRCLES
insheet using "${DATA}/Raw Data/Administrative Data/120904 Crosswalk to Randomization_All.csv", comma clear

drop if rand_circle_id == .
	
rename q4_2013_circle_id circle_id	
keep circle_id
drop if circle_id == .
duplicates drop

* Merge in control circles
merge 1:1 circle_id using `impl'
drop _merge

foreach var of varlist *_impl* {
	replace `var' = 0 if `var' == .
}
	
tempfile implement
save `implement'

u "${DATA}/Cleaned Data/Randomization/130506 Cleaned Phase III Randomization.dta", clear
keep if fyear == 2013
keep circle_id _select_c REV_sel REVPLS_sel CFW_sel INFO_sel stratdum_c*

** KM 140507: Adjustment for non-consenting circles
local nonconsenting  300800 402100 501000 501500 502200 502800 504902 508700

foreach circle of local nonconsenting {
	replace REV_sel = 1/3 if circle_id == `circle'
	replace REVPLS_sel = 1/3 if circle_id == `circle'
	replace CFW_sel = 1/3 if circle_id == `circle'
}

tempfile sel
save `sel'

insheet using "${DATA}/Raw Data/Administrative Data/120904 Crosswalk to Randomization_All.csv", comma clear

drop if rand_circle_id == .

keep rand_circle_id q4_2013_circle_id
duplicates drop

rename rand_circle_id circle_id

merge m:1 circle_id using `sel'
assert _merge == 3
drop _merge

rename circle_id rand_circle_id
rename q4_2013_circle_id circle_id	

sort circle_id rand_circle_id
duplicates drop

ds *circle_id, not
local select_vars `r(varlist)'

bys circle_id: gen j = _n
reshape wide rand_circle_id *sel* stratdum_c*, i(circle_id) j(j)

drop rand_circle_id*

foreach var in `select_vars' {
	egen `var'_xw = rowmean(`var'1 `var'2)
	drop `var'1 `var'2
}

merge 1:1 circle_id using `implement'
assert _merge == 3
drop _merge

saveold "Coded Data/Inspector Treatment Variables", replace
