****** Revenue_Supervisors ******
****** Revenue_Supervisors ******
****** Revenue_Supervisors ******
****** Revenue_Supervisors ******

/*
	Main regressions of supervisor treatment on recovery outcomes.
	Columns separate total, current, and arrears.
	
	Use randomization inference (RI) because we over-reject with regular
	clustered standard errors.
	
	Do file uses rireg.ado, a custom ado file written for running a randomization inference
	regression. 
	
	We save the coefficients and RI p values directly to the dataset and then save those out
	in an excel file in order to simulate using something like outreg.
	
*/


clear all
pr drop _all
cap log close
set more off
set mem 500m
set matsize 800
*set matsize 4000
*set maxvar 32767
pause on

cap cd "${PAPER_ANALYSIS}"
adopath ++ "Do Files/Ado Files"

********************************

local ynow = 2013
local qnow = 4

local iter = 1000 // typically 1000

*************
* 1. Part A: Just supervisors
*************


u "Coded Data/Phase III Analysis Data.dta", clear

* SET UP TABLE
g count = _n in 1/7
g Variables = ""
replace Variables = "N" if count==7
forv q = 1/4 {
	g Q`q' = ""
	}

* REGRESSIONS
forv q = 1/`qnow' {
	forv z = 1/3 {
		local x : word `z' of t c a
		local row1 = `z'*2 - 1
		local row2 = `z'*2
		replace Variables = "Total Recovery (`x')" if count==`row1'
		* Test
		rireg using "Coded Data/rerand_supervisor.dta" if fyear == 2013 & qtr == `q', ///
			y(ln_recov_tot_`x') x(_impl_s) z(_select_s) control(base_ln_recov_tot_`x' stratdum_s*) cl(ETO_clus) iter(`iter')
		* Coefficient and SE
		matrix tmat = e(coef)
		local d = tmat[1,1]
		local d = round(`d',.001)
		replace Q`q' = "`d'" if count==`row1'
		matrix tmat = e(pval)
		local e = tmat[1, 1]
		local e = round(`e',.001)
		replace Q`q' = "["+substr("`e'",1,4)+"]" if count==`row2'
		* Significance
		local sig = _b[_impl_s]/_se[_impl_s]
		if 2*(1-normal(abs(`sig')))<.1 replace Q`q' = Q`q'+"*" if count==`row1'
		if 2*(1-normal(abs(`sig')))<.05 replace Q`q' = Q`q'+"*" if count==`row1'
		if 2*(1-normal(abs(`sig')))<.01 replace Q`q' = Q`q'+"*" if count==`row1'
		* Count
		local count`z' = `e(N)'
		}
	assert abs(`count2'-`count1')<10
	assert abs(`count3'-`count2')<10
	if `count2'>`count1' local count1 = `count2'
	if `count3'>`count1' local count1 = `count3'
	replace Q`q' = "`count1'" if count==7
	}
	

outsheet Variables Q? in 1/7 using "${RI_OUTPUT}/Revenue_Supervisors_RI.csv", comma replace




*************
* 2. Extra coding
*************

u "Coded Data/Phase III Analysis Data.dta", clear

* CODE INTERACTIONS
foreach v of varlist REV_sel REVPLS_sel CFW_sel INFO_sel _select_c {
	g sup`v' = _select_s*`v'
	}
foreach v of varlist REV_impl REVPLS_impl CFW_impl INFO_impl _impl_c  {
	g sup`v' = _impl_s*`v'
	}

* Note that circle clusters are nested within ETO clusters, automatically



	
*************
* 3. Part b: Simple interactions
*************


* REGRESSIONS
foreach x in a {
	forv q = 1/`qnow' {
		* Regress
		rireg using "Coded Data/rerand_supervisor.dta" if fyear == 2013 & qtr == `q', iter(`iter') ///
			y(ln_recov_tot_`x') x(_impl_s _impl_c sup_impl_c) z(_select_s _select_c sup_select_c) control(base_ln_recov_tot_`x' divdum*) cl(ETO_clus)
		* Outreg
		if `q'==1 local a = "replace"
		else local a = "append"
		outreg2 using "${RI_OUTPUT}/Supervisor_Interactions_`x'_RI"	///
			, `a' ctitle("Q`q'") word stats(coef pval)
		}
	}



