**** Income Effect ****

set more off
clear all

pr drop _all
cap log close
set mem 300m

** Directory for Ben ***
cap cd "C:\Users\bolken\Documents\My Dropbox\Pakistan Property Tax Project\Analysis"
*************************

** Directory for Wayne***
cap cd "C:\Users\wsandhol\Dropbox\Olken\Pakistan Property Tax Project\Analysis"
cap cd "C:\Users\Wayne\Dropbox\Olken\Pakistan Property Tax Project\Analysis"
*************************

** Directory for Kunal***
cap cd "C:\Users\kmangal\Dropbox\Pakistan Property Tax Project Analysis"
cap cd "C:\Users\Kunal\Dropbox\Pakistan Property Tax Project Analysis"
*************************

cap cd "${PAKTAX_ANALYSIS}"

do "Do Files/Paper/programs/all_programs.do"

*******************
* PART II: INCOME EFFECT
*******************

u "Data/Coded Data/Phase III Analysis Data.dta", clear
keep if qtr == 4 & fyear == 2012

sort circle_id qtr
merge m:1 circle_id using "Data/Coded Data/Benchmarks/120410 Phase II Benchmarks - Full Sample"
assert _merge == 3
drop _merge

drop if REVPLS_sel > 0

foreach var of varlist bench* {
	gen ln_`var' = ln(`var')
}

foreach X in c a {
	reg ln_recov_tot_`X' base_ln_recov_tot_`X' ln_bench_q4_`X' if _select_c == 0, robust
	predict p_recov_tot_`X'
	g income_shock_`X' = (exp(p_recov_tot_`X') - bench_q4_`X')
}

g incomeshock = rewardrate * (income_shock_c + income_shock_a)
replace incomeshock = 0 if incomeshock < 0

g lnincomeshock = ln(incomeshock)
replace lnincomeshock = ln(1) if incomeshock <= 0

foreach var of varlist REV_sel REV_impl CFW_sel CFW_impl {
	g incomeshock_`var' = `var' * incomeshock
	g lnincomeshock_`var' = `var' * lnincomeshock 
}


// Divide level income shock by 1,000,000 for scale
*replace incomeshock = incomeshock

*foreach X in t c a {
*	replace recov_tot_`X' = recov_tot_`X' / 1000000
*	replace base_recov_tot_`X' = base_recov_tot_`X' / 1000000
*}

*****
* Regressions
******

gen is = .
gen is_CFW_impl = .
gen is_REV_impl = .

gen is_CFW_sel = .
gen is_REV_sel = .

foreach X in t c a {
	forval j=1/2 {
	
		if `j' == 1 {
			replace is = incomeshock
			replace is_CFW_impl = incomeshock_CFW_impl
			replace is_REV_impl = incomeshock_REV_impl
			
			replace is_CFW_sel = incomeshock_CFW_sel
			replace is_REV_sel = incomeshock_REV_sel
		}
		if `j' == 2 {
			replace is = lnincomeshock
			
			replace is_CFW_impl = lnincomeshock_CFW_impl
			replace is_REV_impl = lnincomeshock_REV_impl
			
			replace is_CFW_sel = lnincomeshock_CFW_sel
			replace is_REV_sel = lnincomeshock_REV_sel
		}
		
		
		if `j' == 1 eststo mod`j'_`X' : ivreg recov_tot_`X' base_recov_tot_`X' bench_q4_c bench_q4_a is (REV_impl is_REV_impl CFW_impl is_CFW_impl = REV_sel is_REV_sel CFW_sel is_CFW_sel) stratdum_c*, cluster(cluster_c)
		if `j' == 2 eststo mod`j'_`X' : ivreg ln_recov_tot_`X' base_ln_recov_tot_`X' ln_bench_q4_c ln_bench_q4_a is (REV_impl is_REV_impl CFW_impl is_CFW_impl = REV_sel is_REV_sel CFW_sel is_CFW_sel) stratdum_c*, cluster(cluster_c)

		if `j' == 1 estadd local modtype = "Level"
		if `j' == 2 estadd local modtype = "Log"

	}
}

forval i=1/2 {
	eststo mod`i' : combine_models2 mod`i'_t mod`i'_c mod`i'_a, headings(A B C)
}
 
label var is_CFW_impl "Flexible Bonus * Income Shock"
label var is_REV_impl "Revenue * Income Shock"

label var is "Income Shock"


# delimit ;
esttab mod1 mod2
	using "Tables\tex\input\income_effect_droprevplus_input.tex", 
	keep(is*)
	order(is_REV_impl  is_CFW_impl is)
	 
	b(a3)
	se(a3)
	
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	nomtitles
	
	eqlabels(
			//Embed latex code into the labels (emphasis)
			"\emph{Panel A: Total Revenue}"
			"\emph{Panel B: Current Revenue}"
			"\emph{Panel C: Arrears Revenue}"
			
			//prefix is added before every eqlabel, and suffix after every exlabel. 
			//Span forces column to span across rows, and @span is the width of the table
			// \addlinespace[1mm] adds extra space before table row. 
			prefix(\addlinespace[2mm] \multicolumn{@span}{l}{) suffix(}) span
	)
		
	//nonumbers // No column numbers
	
	stats(N3 modtype3,
		labels(
			"N" "Values in"
		)	
		fmt(
			"%12.0f" "a3"
		)
	)
	
	label // Use Variable Labels
	nonotes
	
	booktabs // a nicer version of tables
	substitute("<" "$<$")
	fragment
	replace
	;

# delimit cr
eststo clear

** WRITE LaTeX WRAPPER AND COMPILE TO PDF **************************************

local file income_effect_droprevplus

** WRITE TABLE NOTE
file open tablenote using "Tables/tex/notes/`file'_notes.txt", write replace

file write tablenote "Re-estimation of Table 10 dropping Revenue Plus circles."
file write tablenote " The Information treatment is included in the controls."
file write tablenote " Robust standard errors in parentheses."
file write tablenote " Standard errors are clustered by robust partition,"
file write tablenote " the partition of circles such that all circles that merged or split with each other"
file write tablenote " are included within the same partition."
file write tablenote " * p$<$0.10, ** p$<$0.05, *** p$<$0.01"

file close tablenote

texout2 "Tables/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

compiletex "Tables/tex/`file'.tex", ///
  out("..") aux("auxdir/") 

