**** Income Effect ****

set more off
clear all

pr drop _all
cap log close
set mem 300m

** Directory for Ben ***
cap cd "C:\Users\bolken\Documents\My Dropbox\Pakistan Property Tax Project\Analysis"
*************************

** Directory for Wayne***
cap cd "C:\Users\wsandhol\Dropbox\Olken\Pakistan Property Tax Project\Analysis"
cap cd "C:\Users\Wayne\Dropbox\Olken\Pakistan Property Tax Project\Analysis"
*************************

** Directory for Kunal***
cap cd "C:\Users\kmangal\Dropbox\Pakistan Property Tax Project Analysis"
cap cd "C:\Users\Kunal\Dropbox\Pakistan Property Tax Project Analysis"
*************************

cap cd "${PAKTAX_ANALYSIS}"

do "Do Files/Paper/programs/all_programs.do"

*******************
* PART II: INCOME EFFECT
*******************


************************************

set more off

u "Do Files\Paper\calculations\income_effect_infocontrol_standarderror", clear

gen beta = .

tempfile coefs
save `coefs'

u "Data/Coded Data/Phase III Analysis Data.dta", clear
keep if qtr == 4 & fyear == 2012

sort circle_id qtr
merge m:1 circle_id using "Data/Coded Data/Benchmarks/120410 Phase II Benchmarks - Full Sample"
assert _merge == 3
drop _merge

foreach var of varlist bench* {
	gen ln_`var' = ln(`var')
}

foreach X in c a {
	reg ln_recov_tot_`X' base_ln_recov_tot_`X' ln_bench_q4_`X' if _select_c == 0, robust
	predict p_recov_tot_`X'
	g income_shock_`X' = (exp(p_recov_tot_`X') - bench_q4_`X')
}

g incomeshock = rewardrate * (income_shock_c + income_shock_a)

g incomeshock2 = incomeshock + (12 * (20000 + 15000 + 15000))
g lnincomeshock = ln(incomeshock2)

g OBJ_impl = REV_impl + REVPLS_impl
g OBJ_sel = REV_sel + REVPLS_sel

foreach var of varlist REV_sel REV_impl REVPLS_sel REVPLS_impl CFW_sel CFW_impl OBJ_impl OBJ_sel {
	g lnincomeshock_`var' = `var' * lnincomeshock 
}


*****
* Regressions
******

gen is = lnincomeshock
gen is_OBJ_impl = lnincomeshock_OBJ_impl
gen is_CFW_impl = lnincomeshock_CFW_impl
gen is_REV_impl = lnincomeshock_REV_impl
gen is_REVPLS_impl = lnincomeshock_REVPLS_impl

gen is_OBJ_sel = lnincomeshock_OBJ_sel
gen is_CFW_sel = lnincomeshock_CFW_sel
gen is_REV_sel = lnincomeshock_REV_sel
gen is_REVPLS_sel = lnincomeshock_REVPLS_sel
				
forval x = 1/3 {
	local X : word `x' of t c a 
	
	eststo mod1_`X' : ivreg ln_recov_tot_`X' base_ln_recov_tot_`X' ln_bench_q4_c ln_bench_q4_a is (OBJ_impl is_OBJ_impl CFW_impl is_CFW_impl= OBJ_sel is_OBJ_sel CFW_sel is_CFW_sel) stratdum_c*, cluster(cluster_c)		
	
	local obj_beta1_`x' = _b[is_OBJ_impl]
	local cfw_beta1_`x' = _b[is_CFW_impl]
	local is_beta1_`x' = _b[is]

	eststo mod2_`X' : ivreg ln_recov_tot_`X' base_ln_recov_tot_`X' ln_bench_q4_c ln_bench_q4_a is (REV_impl is_REV_impl REVPLS_impl is_REVPLS_impl CFW_impl is_CFW_impl = REV_sel is_REV_sel REVPLS_sel is_REVPLS_sel CFW_sel is_CFW_sel) stratdum_c*, cluster(cluster_c)

	local rev_beta2_`x' = _b[is_REV_impl]
	local revpls_beta2_`x' = _b[is_REVPLS_impl]
	local cfw_beta2_`x' = _b[is_CFW_impl]
	local is_beta2_`x' = _b[is]
	
}

preserve
	u `coefs', clear

	forval j=1/3 {
		replace beta = `obj_beta1_`j'' if t == `j' & model == 1 & variable == 1
		replace beta = `cfw_beta1_`j'' if t == `j' & model == 1 & variable == 2
		replace beta = `is_beta1_`j'' if t == `j' & model == 1 & variable == 5
		
		replace beta = `rev_beta2_`j'' if t == `j' & model == 2 & variable == 2
		replace beta = `rev_beta2_`j'' if t == `j' & model == 2 & variable == 2
		replace beta = `cfw_beta2_`j'' if t == `j' & model == 2 & variable == 4
		replace beta = `is_beta2_`j'' if t == `j' & model == 2 & variable == 5
	}
	
	gen tstat = beta / d
	gen p = 2 * (1 - normal(tstat))
	save `coefs', replace
restore


eststo mod1 : combine_models2 mod1_t mod1_c mod1_a, headings(A B C)

preserve

	u `coefs', clear

	keep if model == 1
	keep if inlist(variable, 1, 2, 5)
	sort t variable
	
	mkmat d, matrix(a)
	matrix a = a'
	matrix colnames a = A:is_OBJ_impl A:is_CFW_impl A:is B:is_OBJ_impl B:is_CFW_impl B:is C:is_OBJ_impl C:is_CFW_impl C:is

	mkmat p, matrix(b)
	matrix b = b'
	matrix colnames b = A:is_OBJ_impl A:is_CFW_impl A:is B:is_OBJ_impl B:is_CFW_impl B:is C:is_OBJ_impl C:is_CFW_impl C:is
	
restore

*matrix a = (`obj1', `cfw1', `is1', `obj2', `cfw2', `is2', `obj3', `cfw3', `is3')
estadd matrix bs_se = a
estadd matrix bs_p = b

eststo mod2 : combine_models2 mod2_t mod2_c mod2_a, headings(A B C)

preserve
	u `coefs', clear

	keep if model == 2
	keep if inlist(variable, 2, 3, 4, 5)
	sort t variable
	
	mkmat d, matrix(a)
	matrix a = a'
	matrix colnames a = A:is_REV_impl A:is_REVPLS_impl A:is_CFW_impl A:is B:is_REV_impl B:is_REVPLS_impl B:is_CFW_impl B:is C:is_REV_impl C:is_REVPLS_impl C:is_CFW_impl C:is	

	mkmat p, matrix(b)
	matrix b = b'
	matrix colnames b = A:is_REV_impl A:is_REVPLS_impl A:is_CFW_impl A:is B:is_REV_impl B:is_REVPLS_impl B:is_CFW_impl B:is C:is_REV_impl C:is_REVPLS_impl C:is_CFW_impl C:is	

restore

matrix colnames a = A:is_REV_impl A:is_REVPLS_impl A:is_CFW_impl A:is B:is_REV_impl B:is_REVPLS_impl B:is_CFW_impl B:is C:is_REV_impl C:is_REVPLS_impl C:is_CFW_impl C:is	

estadd matrix bs_se = a
estadd matrix bs_p = b

label var is_OBJ_impl "Objective * Income Shock"
label var is_CFW_impl "\addlinespace Flexible Bonus * Income Shock"

label var is_REV_impl "Revenue * Income Shock"
label var is_REVPLS_impl "\addlinespace Revenue Plus * Income Shock"

label var is "\addlinespace Income Shock"

# delimit ;
esttab mod1 mod2
	using "Tables\tex\input\income_effect_infocontrol_input.tex", 
	keep(is*)
	order(is_OBJ_impl is_REV_impl is_REVPLS_impl is_CFW_impl is)
	
	cells(b(star fmt(a3) pval(bs_p)) bs_se(par fmt(a3)))
	
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	nomtitles
	
	eqlabels(
			//Embed latex code into the labels (emphasis)
			"\emph{Panel A: Total Revenue}"
			"\emph{Panel B: Current Revenue}"
			"\emph{Panel C: Arrears Revenue}"
			
			//prefix is added before every eqlabel, and suffix after every exlabel. 
			//Span forces column to span across rows, and @span is the width of the table
			// \addlinespace[1mm] adds extra space before table row. 
			prefix(\addlinespace[2mm] \multicolumn{@span}{l}{) suffix(}) span
	)
		
	//nonumbers // No column numbers
	
	stats(N3,
		labels(
			"N"
		)	
		fmt(
			"%12.0f"
		)
	)
	
	label // Use Variable Labels
	nonotes
	
	booktabs // a nicer version of tables
	substitute("<" "$<$" "                    &     b/bs_se   &     b/bs_se   \\" " ")
	fragment
	replace
	;

# delimit cr
eststo clear

** WRITE LaTeX WRAPPER AND COMPILE TO PDF **************************************

local file income_effect_infocontrol

** WRITE TABLE NOTE
file open tablenote using "Tables/tex/notes/`file'_notes.txt", write replace

file write tablenote "Circle-level 2SLS regressions. Dependent Variable is log recovery. "
file write tablenote " The first specification combines Revenue and Revenue Plus"
file write tablenote " into the Objective category. The second specification examines the subtreatments separately."
file write tablenote " Income Shock is calculated as the amount circle staff would have earned under the scheme"
file write tablenote " due to business-as-usual, and is measured in logs."
file write tablenote " Panels A, B, and C separate effects for the different margins of collection."
file write tablenote " The Information treatment is included in the controls."
file write tablenote " Standard errors are calculated by bootstrapping with 1000 iterations over the two-step procedure (i.e. first estimating the income shock, and then estimating the model)."
file write tablenote " The bootstrap is clustered by robust partition,"
file write tablenote " the partition of circles such that all circles that merged or split with each other"
file write tablenote " are included within the same partition."
file write tablenote " * p$<$0.10, ** p$<$0.05, *** p$<$0.01"

file close tablenote

texout2 "Tables/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

compiletex "Tables/tex/`file'.tex", ///
  out("..") aux("auxdir/") 

