/*******************************************************************************
2014 PAPER TABLES - INSPECTOR EFFORT
\\Pakistan Property Tax Project\Analysis\Do Files\Regressions\Phase III\Analysis\
	2014_paper\XXXXXX_who_pays_more_subs.do
Kunal Mangal
18 April 2014
SUMMARY: 
OUTLINE:
NOTES:  This file should produce each table in LaTeX, .csv, .rtf, and .txt.

*******************************************************************************/
version 12
clear all
set more off

cap cd "C:\Users\kmangal\Dropbox\Pakistan Property Tax Project Analysis\"
cap cd "C:\Users\Kunal\Dropbox\Pakistan Property Tax Project Analysis\"

cap cd "C:/Users/wsandhol/Dropbox/Olken/Pakistan Property Tax Project/Analysis/"
cap cd "C:/Users/Wayne/Dropbox/Olken/Pakistan Property Tax Project/Analysis/"

cap cd "${PAKTAX_ANALYSIS}"

do "Do Files/Paper/programs/all_programs.do"

** SETUP AND MACROS ************************************************************


** PREP DATA *******************************************************************

** USE DATA
u "Data\Cleaned Data\Inspector Survey\Inspector Survey Clean.dta", clear
	// from "Do Files\Cleaning\Third Party Survey\131007 Inspector Survey Cleaning.do"

merge 1:1 circle_id using "Data/Coded Data/Inspector Treatment Variables"
list circle_id if _merge == 1, clean
count if _merge == 1
keep if _m == 3
drop _m

drop subtreatment
merge 1:1 circle_id using `vars'
keep if _merge == 3
drop _merge

merge 1:1 circle_id using "Data\Coded Data\Inspector Circle Clusters.dta"
keep if _merge == 3
drop _merge

** MAIN EFFECT *****************************************************************

#delimit ;
local variables
	effort
	hrs_field
	hrs_office
	hrs_total
	pressure_scale
	monit_scale
	monit
	;
#delimit cr


foreach var in `variables' {

*ivreg `var' (_impl_cs _impl_c _impl_s = _select_cs _select_c _select_s) divdum*, cl(ETO_clus)
ivreg `var' ( _impl_s =  _select_s) stratdum_s*, cl(ETO_clus)

}


foreach var in `variables' {
	** Estout - TeX
	eststo `var'_A: ///
	  ivreg `var' (_impl_s_xw = _select_s_xw) stratdum_c*, cl(cluster_c)

	qui sum `var' if _select_s_xw == 0
	estadd scalar ymean = `r(mean)'
	  
	eststo `var'_B: ///
	  ivreg `var' (_impl_cs _impl_c _impl_s = _select_cs _select_c _select_s) stratdum_s*, cl(cluster_c)
	
	qui sum `var' if _select_c == 0 & _select_s == 0
	estadd scalar ymean = `r(mean)'
	
	eststo `var' : combine_models2 `var'_A `var'_B, headings(A B)
}


** TeX OUTPUT ******************************************************************
# delimit ;
esttab pressure_scale monit_scale effort hrs_field hrs_office hrs_total  
	using "Tables\tex\input\inspector_effort_supervisors_input.tex", 
	keep(_impl_c_xw _impl_cs _impl_c _impl_s)
	
	b(%12.3g)
	se(%12.3g)
		
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	mtitles(
	"\specialcell{Pressure from \\ supervisors}"
	"\specialcell{Level of \\ monitoring}"
	"Team Effort"
	"\specialcell{Hours/Day \\ spent in field}"
	"\specialcell{Hours/Day \\ spent in office}"
	"\specialcell{Total hours worked \\ in typical day}"
	  ) // Column headings
		
	eqlabels(
			//Embed latex code into the labels (emphasis)
			"\emph{Panel A: Main Treatment}"
			"\emph{Panel B: Subtreatments}"

			// //prefix is added before every eqlabel, and suffix after every eqlabel. 
			// //Span forces column to span across rows, and @span is the width of the table
			 \addlinespace[1mm] adds extra space before table row. 
			 prefix(\addlinespace[2mm] \multicolumn{@span}{l}{) suffix(}) span
		)
	
	stats(N2 ymean2, 
	  labels("N" "Mean of control group")
	)
	// varwidth(45) wrap // this wraps cells automatically -- doesn't work well
	// width(1.0\hsize) // this makes the table fill the page.
		
	label // Use Variable Labels
	
	nonotes
	  
	booktabs // a nicer version of tables
	substitute("<" "$<$")
	fragment
	replace
	;

# delimit cr
eststo clear
	
******************************************************************

set more off
local file inspector_effort_supervisors


** WRITE TABLE NOTE
file open tablenote using "Tables/tex/notes/`file'_notes.txt", write replace

file write tablenote "Instrumental variables regressions, where treatment status is instrumented with randomization results."
file write tablenote " The unit of observation is a circle, as defined at the time of randomization."
file write tablenote " Pressure from supervisors was assessed on a 5-point Likert scale. Level of monitoring was assessed on a 4 point scale."
file write tablenote " Team Effort is assessed on a 100 point scale."
file write tablenote " 'Treatment' in Panel A includes the 3 subtreatments in Panel B."
file write tablenote " The Information treatment is included in the controls."
file write tablenote " Robust standard errors in parentheses."
file write tablenote " Standard errors are clustered by robust partition,"
file write tablenote " the partition of circles such that all circles that merged or split with each other"
file write tablenote " are included within the same partition."
file write tablenote " * p$<$0.10, ** p$<$0.05, *** p$<$0.01"

file close tablenote

texout2 "Tables/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

compiletex "Tables/tex/`file'.tex", ///
  out("..") aux("auxdir/") 

cap log close
