/*******************************************************************************
2014 PAPER TABLES - INSPECTOR MONITORING
Impact of Treatment on Inspector Monitoring

Kunal Mangal
18 April 2014

*******************************************************************************/
version 12
clear all
set more off

cap cd "${PAPER_ANALYSIS}"

do "Do Files/Paper/programs/all_programs.do"

** SETUP AND MACROS ************************************************************


** PREP DATA *******************************************************************

** USE DATA
u "${DATA}/Cleaned Data/Inspector Survey/Inspector Survey Clean.dta", clear

merge 1:1 circle_id using "Coded Data/Inspector Treatment Variables"
list circle_id if _merge == 1, clean
count if _merge == 1
keep if _m == 3
drop _m

merge 1:1 circle_id using "Coded Data/Inspector Circle Clusters.dta"
keep if _merge == 3
drop _merge

** MAIN EFFECT *****************************************************************

#delimit ;
local variables
	pressure_scale
	monit_scale
	;
#delimit cr

label var _impl_c_xw "Any treatment"
label var REV_impl_xw "Revenue"
label var REVPLS_impl_xw "Revenue Plus"
label var CFW_impl_xw "Flexible Bonus"

foreach var in `variables' {
	** Estout - TeX
	eststo `var'_A: ///
	  ivreg `var' (_impl_c_xw = _select_c_xw) stratdum_c*, cl(cluster_c)
	
	  
	eststo `var'_B: ///
	  ivreg `var' (REV_impl_xw REVPLS_impl_xw CFW_impl_xw =  ///
		REV_sel_xw REVPLS_sel_xw CFW_sel_xw) stratdum_c*, cl(cluster_c)
	
	qui sum `var' if _select_c_xw == 0
	estadd scalar ymean = `r(mean)'
	
	estadd joint REV_impl REVPLS_impl CFW_impl : `var'_B
	estadd equivalence REV_impl REVPLS_impl CFW_impl : `var'_B
	estadd eqavg REV_impl REVPLS_impl CFW_impl, prefix(rvm_): `var'_B
	estadd eqavg CFW_impl REV_impl REVPLS_impl, prefix(ovs_): `var'_B
	
	eststo `var' : combine_models2 `var'_A `var'_B, headings(A B)
}


** TeX OUTPUT ******************************************************************
# delimit ;
esttab 	pressure_scale monit_scale
	using "${TABLE_OUTPUT}/tex/input/inspector_monitoring_infocontrol_input.tex", 
	keep(_impl_c_xw REV_impl_xw REVPLS_impl_xw CFW_impl_xw)
	
	b(%12.3g)
	se(%12.3g)
		
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	mtitles(
	"\specialcell{Pressure from \\ supervisors}"
	"\specialcell{Level of \\ monitoring}"
	  ) // Column headings
		
	eqlabels(
			//Embed latex code into the labels (emphasis)
			"\emph{Panel A: Main Treatment}"
			"\emph{Panel B: Subtreatments}"

			// //prefix is added before every eqlabel, and suffix after every eqlabel. 
			// //Span forces column to span across rows, and @span is the width of the table
			 \addlinespace[1mm] adds extra space before table row. 
			 prefix(\addlinespace[2mm] \multicolumn{@span}{l}{) suffix(}) span
		)
	
	stats(N2 ymean2, 
	  labels("N" "Mean of control group")
	)
	// varwidth(45) wrap // this wraps cells automatically -- doesn't work well
	// width(1.0\hsize) // this makes the table fill the page.
		
	label // Use Variable Labels
	
	nonotes
	  
	booktabs // a nicer version of tables
	substitute("<" "$<$")
	fragment
	replace
	;

# delimit cr
eststo clear
	
******************************************************************

set more off
local file inspector_monitoring_infocontrol


** WRITE TABLE NOTE
file open tablenote using "${TABLE_OUTPUT}/tex/notes/`file'_notes.txt", write replace

file write tablenote "This table examines the impact of performance pay on inspectors' perception of monitoring by supervisors. We use instrumental variables regressions, where treatment status is instrumented with randomization results."
file write tablenote " The unit of observation is a circle, as defined at the end of Year 2."
file write tablenote " Pressure from supervisors was assessed on a 5-point Likert scale. Level of monitoring was assessed on a 4 point scale."
file write tablenote " The Information treatment is included in the controls."
file write tablenote " Robust standard errors in parentheses."
file write tablenote " Standard errors are clustered by a robust partition of circles,"
file write tablenote " i.e. the group of circles such that all circles that merged or split with each other"
file write tablenote " are included within the same partition."
file write tablenote " * p$<$0.10, ** p$<$0.05, *** p$<$0.01"

file close tablenote

texout2 "${TABLE_OUTPUT}/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

compiletex "${TABLE_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/") 

cap log close
