/*******************************************************************************
NUMBER REASSESSED
Impacts on Number of Reassessments

Wayne Aaron Sandholtz
27 January 2014

*******************************************************************************/
version 12
clear all
set more off
set matsize 800

cap cd "${PAPER_ANALYSIS}"

do "Do Files/Paper/programs/all_programs.do"

** PREP *****
u "${DATA}/Cleaned Data/Field Survey/Round 3/Cleaned/Sec9_Title_Count.dta", clear

** GENERATE NEW VARIABLES
gen new_y2 = S9TITLE_q4a + S9TITLE_q5a
gen new_y1 = S9TITLE_q6a + S9TITLE_q7a
gen new_y0 = S9TITLE_q9a + S9TITLE_q10a

gen new = new_y2 + new_y1

gen reassess_y2 = S9TITLE_q4b + S9TITLE_q5b
gen reassess_y1 = S9TITLE_q6b + S9TITLE_q7b
gen reassess_y0 = S9TITLE_q9b + S9TITLE_q10b

gen reassess = reassess_y2 + reassess_y1

gen total_y2 = new_y2 + reassess_y2
gen total_y1 = new_y1 + reassess_y1
gen total_y0 = new_y0 + reassess_y0

gen total = total_y2 + total_y1

merge m:1 circle_id using "Coded Data/Survey Circle Clusters"
assert _merge == 3 if !inlist(circle_id, 400400, 402502, 506901, 507100, 800521)
drop _merge

* Fixing the circle coding problem
replace circle_id = 612200 if circle_name == "MODEL TOWN-EXT-I"
replace circle_id = 612300 if circle_name == "MODEL TOWN-EXT-II"

* Merge in Treatment Variables
merge m:1 circle_id using "Coded Data/Survey Treatment Variables"
assert _merge == 3
drop _merge

drop if REVPLS_sel_xw == 1

label var _impl_c_xw "Treatment"

** REGRESSIONS *****************************************************************

foreach var in total new reassess {

	eststo `var': ///
	  ivreg `var' (_impl_c_xw = _select_c_xw) reassess_y0 new_y0 stratdum_c*, cluster(cluster_c)
	
	qui sum `var'_y2 if e(sample) == 1 & _select_c_xw == 0
	estadd scalar ysumm = `r(mean)' 	

	}
	
** TeX output, Panel A *********************************************************

# delimit ;
esttab total new reassess
	using "${TABLE_OUTPUT}/tex/input/number_properties_input.tex", 
	keep(_impl_c_xw)
	
	b(%12.1f)
	se(%12.2f)
	
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	mtitles(
		"\specialcell{Total Number of Section 9 Properties \\ Added to Tax Rolls \\ in Treatment Period}"
		"\specialcell{Number of New Properties \\ Added to Tax Rolls \\ in Treatment Period}"
		"\specialcell{Number of Reassessed Properties \\ Added to Tax Rolls \\ in Treatment Period}"
	) // Column headings
	
	
	stats(N ysumm,
		labels(
			"N"
			"Mean of control group"
		)	
		fmt(
			"%12.0f" "%12.1f"
		)
	)
	
	label // Use Variable Labels
	
	nonotes
	
	booktabs // a nicer version of tables
	substitute("<" "$<$")
	fragment
	replace
	;

# delimit cr

eststo clear

** WRITE LaTeX WRAPPER AND COMPILE TO PDF **************************************

set more off
local file number_properties


** WRITE TABLE NOTE
file open tablenote using "${TABLE_OUTPUT}/tex/notes/`file'_notes.txt", write replace

file write tablenote "This table presents results on the impact of performance pay schemes on the number of properties that experience a change in tax status."
file write tablenote " Column 1 presents treatment effects on the total number of such properties added. The next two columns disaggregate this effect by"
file write tablenote " whether the property is reported to have been previously registered on the tax rolls (Column 3) or not (Column 2)."
file write tablenote " The sample consists of circles surveyed in Phase 2 (see text for details)."
file write tablenote " Specification includes stratum fixed effects and controls for number of new and reassessed properties added"
file write tablenote " in the pre-treatment (FY 2011) fiscal year."
file write tablenote " Standard errors are clustered by robust partition,"
file write tablenote " the partition of circles such that all circles that merged or split with each other"
file write tablenote " are included within the same partition."
file write tablenote " * p$<$0.10, ** p$<$0.05, *** p$<$0.01"

file close tablenote


texout2 "${TABLE_OUTPUT}/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

compiletex "${TABLE_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/") 
  
cap log close
