/*******************************************************************************
ADDITIONAL SATISFACTION / QUALITY MEASURES
Impacts on Satisfaction with the Government

Kunal Mangal
17 June 2014

*******************************************************************************/
version 12
clear all
set more off
set matsize 800

cap cd "${PAPER_ANALYSIS}"

do "Do Files/Paper/programs/all_programs.do"

*******************************************************************************/

use "Coded Data/survey_coded_data.dta", clear

keep if SEC9 == 0

gen pickupnote = (5 - SEC3_q14) / 4

gen vote_inpower = 0
foreach var of varlist SEC5_q4_1-SEC5_q4_16 {
	replace vote_inpower = 1 if `var' == 3
}
replace vote_inpower = . if SEC5_q4_1 == .

***********************************************************

foreach yvar in elec_quality water_quality elec_satisfied water_satisfied pickupnote vote_inpower {
	* Regress - Main Treatment - Part A
	eststo `yvar'_A : ///
	  ivreg `yvar' (_impl_c_xw =_select_c_xw) short_dummy stratdum_c* if phase == 1, ///
		cluster(cluster_c)

	* Regress - Subtreatments - Panel B
	eststo `yvar'_B : ///
	  ivreg `yvar' (REV_impl_xw REVPLS_impl_xw CFW_impl_xw = ///
		REV_sel_xw REVPLS_sel_xw CFW_sel_xw) ///
	    short_dummy stratdum_c* if phase == 1, cluster(cluster_c)


	qui sum `yvar' if e(sample) == 1 & _select_c_xw == 0
	estadd scalar ysumm	= `r(mean)'
	estadd local samp = "Phase 1"
	
	estadd joint REV_impl REVPLS_impl CFW_impl : `yvar'_B 
	estadd equivalence REV_impl REVPLS_impl CFW_impl: `yvar'_B
	estadd eqavg REV_impl REVPLS_impl CFW_impl, prefix(rvm_): `yvar'_B
	estadd eqavg CFW_impl REV_impl REVPLS_impl, prefix(ovs_): `yvar'_B
			
	eststo `yvar' : combine_models2 `yvar'_A `yvar'_B, headings(A B)
}

# delimit ;
esttab elec_quality water_quality elec_satisfied water_satisfied pickupnote vote_inpower
	using "${TABLE_OUTPUT}/tex/input/satisfaction_infocontrol_input.tex", 
	keep(_impl_c_xw REV_impl_xw REVPLS_impl_xw CFW_impl_xw)
	
	b(%12.3f)
	se(%12.3f)
	
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	mtitles("\specialcell{Quality of \\ Electricity Dept.}" 
			"\specialcell{Quality of \\ Water Dept.}"
			"\specialcell{Satisfaction with \\ Electricity Dept.}"
			"\specialcell{Satisfaction with \\ Water Dept.}"
			"\specialcell{Likelihood of Picking \\ up Note}"
			"\specialcell{Indicated Preference \\ for Incumbent Party}") // Column headings
	
	eqlabels(
			//Embed latex code into the labels (emphasis)
			"\emph{Panel A: Main Treatment}"
			"\emph{Panel B: Subtreatments}"
			
			//prefix is added before every eqlabel, and suffix after every exlabel. 
			//Span forces column to span across rows, and @span is the width of the table
			// \addlinespace[1mm] adds extra space before table row. 
			prefix(\addlinespace[2mm] \multicolumn{@span}{l}{) suffix(}) span
		)
		
	//nonumbers // No column numbers
	
	stats(N2 samp2 ysumm2 rvm_eqavg2 ovs_eqavg2 equivalence2 joint2,
		labels(
			"N"
			"Sample"
			"Mean of control group"
			"Rev. vs. Multitasking p."
			"Objective vs. Subjective p."
			"Equality of Schemes"
			"Joint significance"
		)	
		fmt(
			"%12.0f" "a3" "%12.3f" "%12.3f" "%12.3f" "%12.3f" "%12.3f"
		)
	)
	
	label // Use Variable Labels
	nonotes
	addnote("Robust standard errors, clustered by circle, in parentheses"
	  "* p<0.10, ** p<0.05, *** p<0.01")
	
	booktabs // a nicer version of tables
	substitute("<" "$<$")
	fragment
	replace
	;

# delimit cr
eststo clear


** WRITE LaTeX WRAPPER AND COMPILE TO PDF **************************************

set more off
local file satisfaction_infocontrol

/*
** WRITE TABLE NOTE
file open tablenote using "${TABLE_OUTPUT}/tex/notes/`file'_notes.txt", write replace

file write tablenote "Property level 2SLS regressions."
file write tablenote " Quality and Satisfaction were measured on a 5 point Likert scale and re-scaled to a [0,1] interval."
file write tablenote " Likelihood of Picking up Note is the respondent's assessment (on a 5 point scale, also re-scaled to a [0,1] interval)"
file write tablenote " of how likely a stranger would return them a Rs. 1000 they had accidentally dropped."
file write tablenote " Indicated Preference for Incumbent Party is a binary variable = 1 if the respondent indicates that any member of the"
file write tablenote " household voted for the incumbent party at either the provincial or national level in the most recent elections."
file write tablenote " Sample restricted to circles surveyed in Phase 1. Specification includes strata fixed effects and controls for whether"
file write tablenote " the property was surveyed using the short version of the survey." 
file write tablenote " Information treatment included in the control group. Robust standard errors, clustered by robust"
file write tablenote " partition, in parentheses. * p$<$0.10, ** p$<$0.05, *** p$<$0.01"

file close tablenote
*/

texout2 "${TABLE_OUTPUT}/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

compiletex "${TABLE_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/") 
  
