/*******************************************************************************
2014 PAPER TABLES - SUPERVISORY OUTCOMES - INTERACTIONS

Kunal Mangal
April 23 2014
SUMMARY: 
OUTLINE:
NOTES:  This file should produce each table in LaTeX, .csv, .rtf, and .txt.

*******************************************************************************/
version 12
clear all
set more off

cap cd "${PAPER_ANALYSIS}"

do "Do Files/Paper/programs/all_programs.do"

** REGRESSIONS *****************************************************************

* RI P values
foreach x in t c a {

	insheet using "${RI_OUTPUT}\Supervisor_Interactions_`x'_RI.txt", clear
	keep if v1 == "" // standard errors on blank rows
	keep in 3/6
	keep v5
	destring v5, ignore("()") replace
	mkmat v5 , matrix(RI_se)

	matrix RIse_`x' = RI_se[1,1], RI_se[2,1], RI_se[3,1]
	matrix colnames RIse_`x' = _impl_s _impl_c _impl_cs

}

 
use "Coded Data/Phase III Analysis Data.dta", clear
keep if fyear == 2013
keep if qtr == 4

label var _impl_c "Inspector treatment"
label var _impl_s "Supervisory treatment"

label var REV_impl "Revenue"
label var REVPLS_impl "Revenue Plus"
label var CFW_impl "Flexible Bonus"
label var INFO_impl "Information"

gen _select_cs = _select_c * _select_s
gen _impl_cs = _impl_c * _impl_s

label var _impl_cs "Inspector Treatment * Supervisory Treatment"


foreach x in t c a {
	
	* Regress - Main Treatment - Panel A
	eststo main_`x' : ///
	  ivreg ln_recov_tot_`x' base_ln_recov_tot_`x' (_impl_cs _impl_s _impl_c = _select_cs _select_s _select_c) ///
		divdum*, cluster(ETO_clus)
	
	qui sum ln_recov_tot_`x' if _select_s == 0 & _select_c == 0
	estadd scalar ymean = `r(mean)'
	
	estadd matrix RIse = RIse_`x'
}
	
# delimit ;
esttab main_t main_c main_a
	using "${TABLE_OUTPUT}\tex\input\supervisory_interaction_infocontrol_input.tex", 
	keep(_impl_s _impl_c _impl_cs)
	order(_impl_s _impl_c _impl_cs)
	
	cells(b(fmt(3) star pval(RIse)) RIse(par([ ])))
	
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	mtitles("Total" "Current" "Arrears")
		
	nonumbers // No column numbers
	
	stats(N ymean,
		labels(
			"N" 
			"Mean of control group"
		)	
		fmt(
			"%12.0f" "%12.3f"
		)
	)
	
	label // Use Variable Labels
	
	booktabs // a nicer version of tables
	substitute("                    &      b/RIse   &      b/RIse   &      b/RIse   \\" "")
	fragment
	replace
	;

# delimit cr
eststo clear

** WRITE LaTeX WRAPPER AND COMPILE TO PDF **************************************

set more off
local file supervisory_interaction_infocontrol

/*
** WRITE TABLE NOTE
file open tablenote using "Tables/tex/notes/`file'_notes.txt", write replace

file write tablenote "Instrumental variables regressions, where both supervisory and circle treatments are instrumented with randomization results."
file write tablenote " The unit of observation is a circle, as defined at the time of randomization."
file write tablenote " Columns separate margins of collection."
file write tablenote " Specification include division fixed effects and baseline log revenue collection."
file write tablenote " Mean of control group reflects mean for pure controls, i.e. circles that did not participate in either the inspector or supervisory treatments."
file write tablenote " The Information treatment is included in the controls."
file write tablenote " Randomization inference based p-values in brackets."
file write tablenote " * p$<$0.10, ** p$<$0.05, *** p$<$0.01"

file close tablenote
*/

texout2 "${TABLE_OUTPUT}/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

compiletex "${TABLE_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/") 
