/*******************************************************************************
WHO GETS RE-ASSESSED

Information Treatment OUT of controls

Wayne Aaron Sandholtz
27 January 2014

*******************************************************************************/
version 12
clear all
set more off
set matsize 800

cap cd "${PAPER_ANALYSIS}"

do "Do Files/Paper/programs/all_programs.do"

** PREP ************************************************************************

** DEFINE VARIABLE LISTS
#delimit ;
	
global panela
	GARV
	floors
	last_renovation2
	land_area
	tot_cov_area
	main_road
	category_scale
	pctcom
	pctcomrent
	tax_liability
	;
	
global panelb
	age
	educ_yrs
	wages
	expenditure_hat
	connect_political
	connect_pgp
	;	
#delimit cr

** ************************************************************


** USE DATA
use "Coded Data/survey_coded_data.dta", clear
			
** LABEL VARIABLES
la var _impl_c_xw "Treatment"
la var SEC9 "Re-assess dummy"
la var SEC9_impl_c_xw "Re-assess * Treatment"
la var SEC9INFO_impl_xw "Re-assess * Information"


foreach x in a b {
	foreach var in ${panel`x'}{
		eststo `var': ///
		  ivreg `var' (SEC9_impl_c_xw SEC9INFO_impl_xw = SEC9_select_c_xw SEC9INFO_sel_xw) ///
		    SEC9 short_dummy circlefe* , cluster(cluster_c)
		
		
		qui sum `var' if e(sample) == 1 & _select_c_xw == 0 & SEC9 == 0 & INFO_sel_xw == 0
		estadd scalar ysumm = `r(mean)'
		
	}
}

** TeX output, Panel A *********************************************************

# delimit ;
esttab $panela
	using "${TABLE_OUTPUT}/tex/input/who_gets_reassessed_main_infoout_a_input.tex", 
	keep(SEC9_impl_c_xw SEC9INFO_impl_xw SEC9)
	
	b(%12.3f)
	se(%12.3f)
	
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	mtitles(
		"\specialcell{GARV}"
		"\specialcell{Number of \\ floors}"
		"\specialcell{Last \\ renovation \\ was $\leq$ 2 \\ years ago}"
		"\specialcell{Land area \\ (sq. feet)}"
		"\specialcell{Total \\ covered area, \\ all uses}"
		"\specialcell{Main \\ Road}"
		"\specialcell{Category}"
		"\specialcell{Percent of \\ property \\ commercial}"
		"\specialcell{Percent of \\ property \\ commercial \\ and rented}"
		"\specialcell{Tax \\ Liability}"
		) // Column headings
	

	nonumbers // No column numbers
	
	stats(N ysumm,
		labels(
			"N"
			"Mean of control group in gen. pop. sample"
		)	
		fmt(
			"%12.0f" "%12.3f"
		)
	)

	
	mgroups(" " "Components of GARV" "",
		pattern(1 0 0 1 0 0 0 0 0 1)
		prefix(\multicolumn{@span}{c}{)
		suffix(}) span erepeat(\cmidrule(lr){@span})
	)
	
	
	label // Use Variable Labels
	nonotes	
	booktabs // a nicer version of tables
	substitute("<" "$<$")
	replace
	;

# delimit cr

** TeX output, Panel B *********************************************************

# delimit ;
esttab $panelb
	using "${TABLE_OUTPUT}/tex/input/who_gets_reassessed_main_infoout_b_input.tex", 
	keep(SEC9_impl_c_xw SEC9INFO_impl_xw SEC9)
	
	b(%12.3f)
	se(%12.3f)
	
	starlevels(* .10 ** .05 *** .01) // significance levels
	
	mtitles(
		"\specialcell{Approximate \\ age of owner}"
		"\specialcell{Owner's level \\ of education}"
		"\specialcell{Per-capita \\ wages}"
		"\specialcell{Predicted \\ expenditure \\ given assets}"
		"\specialcell{Connected \\ to Politician}"
		"\specialcell{Connected \\ to Politician/ \\ Government/ \\ Police}"
	) // Column headings
	

	nonumbers // No column numbers
	
	stats(N ysumm,
		labels(
			"N"
			"Mean of control group in gen. pop. sample"
		)	
		fmt(
			"%12.0f" "%12.3f"
		)
	)
	
	label // Use Variable Labels
	
	nonotes
	booktabs // a nicer version of tables
	fragment
	replace
	;

# delimit cr
eststo clear

** WRITE LaTeX WRAPPER *********************************************************

set more off
local file who_gets_reassessed_main_infoout


** WRITE TABLE NOTE
file open tablenote using "${TABLE_OUTPUT}/tex/notes/`file'_notes.txt", write replace

file write tablenote "This table re-estimates Table 8 from the main text, separating the Information treatment from the control group. See Notes to Table 8 for additional information."
file write tablenote " * p$<$0.10, ** p$<$0.05, *** p$<$0.01"

file close tablenote
*
file open tablenotefile using "${TABLE_OUTPUT}/tex/notes/`file'_notes.txt", read
file read tablenotefile noteline


** Write the file **********************************************************
# delimit ;
cap file close x;
file open x using "${TABLE_OUTPUT}/tex/`file'.tex" ///
  , write replace;
foreach thing in 
`"\documentclass[preview, varwidth=\maxdimen, border=10pt]{standalone} 	"'
`"\usepackage{amsmath}                                                  "'
`"\usepackage{amsfonts}                                                 "'
`"\usepackage{booktabs}                                                 "'
`"\usepackage{threeparttable}                                           "'
`"\usepackage{titlesec}                                                 "'
`"                                                                      "'
`"% This is for word wrap in cells in tables.                           "'
`"\newcommand{\specialcell}[2][c]{%                                     "'
`"\begin{tabular}[#1]{@{}c@{}}#2\end{tabular}}                          "'
`"                                                                      "'
`"\titleformat{\section}                                                "'
`"  {\normalfont\scshape}{\thesection}{1em}{}                           "'
`"                                                                      "'
`"\begin{document}                                                      "'
`"\begin{table}[htp]                                                    "'
`"\scriptsize                                                           "'
`"\emph{Panel A}\\"'
`"\input{"input/`file'_a_input.tex"}		                           	"'
`"\end{table}                                                           "'
`"\begin{table}[htp]                                                    "'
`"\scriptsize                                                           "'
`"\emph{Panel B}\\"'
`"\begin{threeparttable}												"'
`"\begin{tabular}{l*{6}{c}}									            "'
`"\toprule																"'
`"\input{"input/`file'_b_input.tex"}		                          	"'
`"\bottomrule															"'
`"\end{tabular}														    "'
`"\begin{tablenotes}													"'
`"\item \scriptsize \emph{Notes}: `noteline'							"'
`"\end{tablenotes}														"'
`"\end{threeparttable}													"'
`"\end{table}                                                           "'
`"\end{document}                                                        "'{;
	file write x `"`thing'"' _n;
};
file close x;
# delimit cr
****************************************************************************

file close tablenotefile

** COMPILE *********************************************************************

compiletex "${TABLE_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/") 
	

cap log close
