/*******************************************************************************
SUMMARY STATS - FULL

Kunal Mangal
25 April 2014

*******************************************************************************/
version 12
clear all
set more off
set matsize 800

cap cd "${PAPER_ANALYSIS}"

do "Do Files/Paper/programs/all_programs.do"

*******************************************************************************

/* Admin Data */

# delimit ;
local vars1 
	ln_recov_tot_t
	ln_recov_tot_c
	ln_recov_tot_a
	
	ln_gross_dem_t
	ln_gross_dem_c
	ln_gross_dem_a
	
	ln_recoveryrate_t
	ln_recoveryrate_c
	ln_recoveryrate_a
	
	ln_nonexemptrate_t
	ln_nonexemptrate_c
	ln_nonexemptrate_a
;
# delimit cr


use "Coded Data/Phase III Analysis Data.dta", clear
keep if qtr == 4
keep circle_id fyear `vars1'

order circle_id fyear ln_recov_tot_t ln_recov_tot_c ln_recov_tot_a ln_gross_dem_t ln_gross_dem_c ln_gross_dem_a ///
	ln_nonexemptrate_t ln_nonexemptrate_c ln_nonexemptrate_a ln_recoveryrate_t ln_recoveryrate_c ln_recoveryrate_a ///
	
reshape wide `vars1', i(circle_id) j(fyear)

forval year = 2012/2013 {
	forval z =1/3 {
		local x : word `z' of t c a
		local y : word `z' of Total Current Arrears
		
		label var ln_recov_tot_`x'`year' "Log Revenue (`y') FY `year'"
		label var ln_gross_dem_`x'`year' "Log Tax Base (`y') FY `year'"
		label var ln_recoveryrate_`x'`year' "Log Recovery Rate (`y') FY `year'"
		label var ln_nonexemptrate_`x'`year' "Log Non-Exemption Rate (`y') FY `year'"
	}
}

ds circle_id, not
eststo admin: estpost tabstat `r(varlist)', statistics(mean sd N) columns(statistics)
esttab admin using "${TABLE_OUTPUT}/tex/input/summary_stats_full_input.tex", ///
	cells("mean(label(Mean) fmt(2)) sd(label(SD) fmt(2)) count(label(N) fmt(0))") ///
	nostar noobs nonumbers nomtitles nonote label booktabs fragment ///
	substitute("\midrule" "\midrule \emph{Panel A: Administrative Data}\\ \midrule") ///
	replace

/* Survey Data */
use "Coded Data/survey_coded_data", clear

# delimit ;
local vars
	BM_match

	tax_quality
	tax_satisfied

	diff_GARV
	diff_pct_GARV
	
	GARV
	
	tax_last_payment
	tax_last_payment_1011

	tax_corruption
	
	tax_payment_total2
	tax_times_payment 
		
	floors
	last_renovation2
	land_area
	tot_cov_area
	main_road
	category_scale
	pctcom
	pctcomrent
		
	age
	educ_yrs
	wages
	expenditure_hat
	connect_political
	connect_pgp
;
# delimit cr

egen tax_payment_total2 = rowmean(tax_unofficial_payment_short?) if source == "short"
replace tax_payment_total2 = tax_payment_total if source ! = "short"

label var tax_last_payment "Self-reported tax payment in FY 2013"
label var tax_last_payment_1011 "Self-reported tax payment in FY 2011"

label var diff_GARV "Inaccuracy"
label var diff_pct_GARV "Tax Gap"

label var tax_payment_total2 "Bribe Payment"
label var tax_times_payment "Frequency of Bribe Payment"

label var floors "Number of floors"
label var category_scale "Taxation category (1-7)"

label var land_area "Land Area (sq. ft.)"
label var tot_cov_area "Total Covered Area (sq. ft.)"

label var tax_quality "Quality of Tax Department [0-1]"
label var tax_satisfied "Satisfaction with Tax Department [0-1]"
label var tax_corruption "Degree of Corruption in Tax Department [0-1]"

label var pctcom "Fraction of covered area - Commercial"
label var pctcomrent "Fraction of covered area - Commercial and Rented"
	
label var main_road "On Main Road"
label var last_renovation2 "Last Renovation was $\leq$ 2 years ago"

label var age "Age of owner"
label var educ_yrs "Owner's level of education"

* Drop sample for Phase 1 variables
foreach var of varlist tax_payment_total2 tax_quality tax_satisfied tax_times_payment tax_corruption {
	replace `var' = . if phase != 1
}


eststo random : estpost tabstat `vars' if SEC9 == 0, statistics(mean sd count) columns(statistics)
esttab random using "${TABLE_OUTPUT}/tex/input/summary_stats_full_input.tex", ///
	cells("mean(label(Mean) fmt(%12.2gc)) sd(label(SD) fmt(%12.2gc)) count(label(N) fmt(%12.0gc))") nostar noobs nonumbers nomtitles nonote label booktabs fragment append ///
	substitute("                    &        Mean&          SD&           N\\" "\\ \emph{Panel B: Survey Data} \\")


/* Inspector Data */
use "${DATA}/Cleaned Data/Inspector Survey/Inspector Survey Clean", clear

keep if status == 1

# delimit ;
local vars 
	effort
	hrs_field
	hrs_office
	hrs_total
	pressure_scale
	monit_scale
;
# delimit cr

eststo inspector : estpost tabstat `vars', statistics(mean sd count) columns(statistics)
esttab inspector using "${TABLE_OUTPUT}/tex/input/summary_stats_full_input.tex", ///
	cells("mean(label(Mean) fmt(%12.2gc)) sd(label(SD) fmt(%12.2gc)) count(label(N) fmt(0))") nostar noobs nonumbers nomtitles nonote label booktabs fragment append ///
	substitute("                    &        Mean&          SD&           N\\" "\\ \emph{Panel C: Inspector Survey Data} \\")


*******************************************

set more off
local file summary_stats_full

/*
** WRITE TABLE NOTE
file open tablenote using "Tables/tex/notes/`file'_notes.txt", write replace

file write tablenote "Panel A statistics are crosswalked to the original 482 randomization circles."
file write tablenote " Panel B statistics are for random sample properties only. Subjective variables - i.e., Bribe Payment,"
file write tablenote " Tax $+$ Bribe Payment, and Frequency of Bribe Payment - are reported for Phase 1 circles only."
	
file close tablenote
*/

texout2 "${TABLE_OUTPUT}/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

compiletex "${TABLE_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/") 
  

