*******************************
* EXPERIMENTAL DESIGN
*******************************

set more off
clear all

cap cd "${PAPER_ANALYSIS}"

do "Do Files/Paper/programs/all_programs.do"

*****************************************************************************

/*
	Directions from Ben:
	
	we need to make a table showing the treatment status.
	
						Lottery		Implementation
		Treatment	Year 1 	Year 2	Year 1 	Year 2
		Rev 			50	70	50	70
		Rev+			50	70	50	70
		Flex Bonus		50	70	50	70
		Info				70		70
		Control			335	202	335	202

	this is the # of randomization level cicles
	a) selected for each treatment
	b) actually implementing each treatment at the end of the year

	these should be randomization-level so should always add to 482
*/

use "Coded Data/treatment_vars", clear

keep circle_id fyear qtr REV* REVPLS* CFW* INFO*
keep if qtr == 4

// Count any circle that's implementing as 1
foreach var of varlist *impl { 
	replace `var' = 1 if `var' > 0
}

// Count objectors (sel1all / sel2all = .333 as 0)

/* Note from Ben:
	You should put them in as randomly selected for treatment and put them 
	1/3 in each of the 3 subtreatments, and we can explain in the notes.
*/

// Generate controls
foreach type in impl sel1all sel2all {
	gen CTRL_`type' = (REV_`type' == 0 & REVPLS_`type' == 0 & CFW_`type' == 0 & INFO_`type' == 0)
}

// Make sure treatments are unique to year
foreach treat in REV REVPLS CFW INFO CTRL {
	replace `treat'_sel1 = 0 if fyear == 2013
	replace `treat'_sel2 = 0 if fyear == 2012
}


collapse (sum) REV* CFW* INFO* CTRL*, by(fyear)

foreach var of varlist REV* CFW* INFO* CTRL* {
	replace `var' = round(`var')
}

keep fyear *sel1all *sel2all *impl

reshape long @_sel1all @_sel2all @_impl, i(fyear) j(treatment) string

gen select = _sel1all + _sel2all
drop _sel1all _sel2all

rename _impl implement

reshape wide select implement, i(treatment) j(fyear)

label define treat 1 "Revenue" 2 "Revenue Plus" 3 "Flexible Bonus" 4 "Information" 5 "Control"

replace treatment = "Revenue" if treatment == "REV"
replace treatment = "Revenue Plus" if treatment == "REVPLS"
replace treatment = "Flexible Bonus" if treatment == "CFW"
replace treatment = "Information" if treatment == "INFO"
replace treatment = "Control" if treatment == "CTRL"

encode treatment, generate(treat) label(treat)
drop treatment

sort treat

order treat select2012 select2013 implement2012 implement2013

estpost tabstat select* implement*, by(treat) nototal
esttab using "${TABLE_OUTPUT}/tex/input/treatment_table_input.tex",  ///
	 c("select2012 select2013 implement2012 implement2013")  style(tex) booktabs label compress fragment replace ///
	noobs nonum nonote collabels("Year 1" "Year 2" "Year 1" "Year 2") mlabels(none) ///
	substitute("                &   Year 1&   Year 2&   Year 1&   Year 2\\" "& \multicolumn{2}{c}{Randomization} & \multicolumn{2}{c}{Implementation} \\                 &   Year 1&   Year 2&   Year 1&   Year 2\\") ///
	nonotes
	
******************************************************************

set more off
local file treatment_table

/*
** WRITE TABLE NOTE
file open tablenote using "Tables/tex/notes/`file'_notes.txt", write replace

file write tablenote "In Year 1, in cases where staff did not consent to treatment after the first ballot, circles were assigned treatment values of 1/3 for each main treatment type (i.e. Revenue, Revenue Plus, and Flexible Bonus)."
file write tablenote " See text for more details. Values are rounded."

file close tablenote
*/

texout2 "${TABLE_OUTPUT}/tex/`file'", ///
  input("input/`file'_input") notes("notes/`file'_notes")

compiletex "${TABLE_OUTPUT}/tex/`file'.tex", ///
  out("..") aux("auxdir/") 
