/*
	Compile Randomization Circles
	
	Compiles admin data so that we get a panel on tax circles IN TERMS OF THEIR current / present
	circle IDs. That is, circles in the dataset will be identified in terms of the IDs set in the 
	locals [ynow] and [qnow].
	
	This do files takes the crosswalke datafiles as inputs and stacks them together
	appropriately.

	Globals referenced here defined in Master Compile.do
*/

clear all
set more off

cap cd "C:/Users/kmangal/Dropbox (CID)/Pakistan Property Tax Project Analysis/"
cap cd "${PAKTAX_ANALYSIS}"

*******************************

** STEP 1 : COMPILE BASELINE VALUES **
* The circles we used for randomization are in between Q4 2011 and Q1 2012. So for some circles we will be merging baseline values
* in terms of crosswalk to Q4 2011, and in some cases we'll be merging in in terms of Q1 2012. Circle 809300 doesn't exist in either
* and so is dealth with separately.

use "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Present - Analysis/2012_q1_crosswalk.dta", clear
keep if inlist(circle_id, 809301, 809302)
keep circle_id *gross_dem* *net_dem* *recov_tot*

collapse (sum) *gross_dem* *net_dem* *recov_tot*
gen circle_id = 809300

tempfile overwrite
save `overwrite'

use "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Present - Analysis/2011_q4_crosswalk.dta", clear
keep if inlist(circle_id, 402300, 403902)
keep circle_id *gross_dem* *net_dem* *recov_tot*

tempfile overwrite2
save `overwrite2'

insheet using "Data/Raw Data/Administrative Data/120904 Crosswalk to Randomization_All.csv", comma clear
keep rand_circle_id
drop if missing(rand_circle_id)
rename rand_circle_id circle_id
duplicates drop

merge 1:1 circle_id using "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Present - Analysis/2012_q1_crosswalk.dta"
drop if _merge == 2
drop _merge 

merge 1:1 circle_id using "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Present - Analysis/2011_q4_crosswalk.dta", update
drop if _merge == 2
drop _merge 

merge 1:1 circle_id using `overwrite', update
drop _merge

merge 1:1 circle_id using `overwrite2', update replace
drop _merge
	
// Only want baseline, which is FY 2011
drop q1_2012*

reshape long @gross_dem_c @gross_dem_a @net_dem_c @net_dem_a @recov_tot_c @recov_tot_a, i(circle_id) j(qtrstring) string

gen qtr = substr(qtrstring, 2, 1)
destring qtr, replace

gen fyear = substr(qtrstring, 4, 4)
destring fyear, replace

drop qtrstring

tempfile base
save `base'

** STEP 2 : COMPILE OUTCOME VALUES **

forval y=2012/2013 {
	forval q = 1/4 {
	
		use "Data/Cleaned Data/Administrative Data/Crosswalk/Quarterly/To Randomization//`y'_q`q'", clear
		gen fyear = `y'
		gen qtr = `q'
		
		if `y' == 2012 & `q' == 1 {
			tempfile data
			save `data'
		}
		else {
			append using `data'
			save `data', replace
		}
	}
}

append using `base'
save `data', replace

** STEP 3 : MERGE IN ANCILLARY INFORMATION **
* Information will be pulled in from the first time the circles show up in the admin data

forval y = 2008/2013 {
	forval q = 1/4 {
		
		use "Data/Cleaned Data/Administrative Data/Quarterly/FY`y' Q`q'/FY`y' Q`q'.dta", clear
		keep division_id division_name district_id district_name zone_id zone_name circle_id circle_name hr_id hr_name eto* aeto*
		
		gen fyear = `y'
		gen qtr = `q'
		
		merge 1:1 circle_id fyear qtr using `data'
		drop if _merge == 1
		drop _merge
		
		save `data', replace
	}
}

foreach var in gross_dem net_dem recov_tot {
	replace `var'_t = `var'_c + `var'_a
}

order fyear qtr division_id division_name district_id district_name ///
	 zone_id zone_name circle_id circle_name hr_id hr_name, first
	
sort circle_id fyear qtr

saveold "Data/Cleaned Data/Administrative Data/Punjab Crosswalked - Randomization Circles.dta", replace
