/*******************************************************************************
*** Cleaning Inspector Survey ***
*** Obeid Rehman 		      ***
*** July 2013				  ***
*********************************

OUTLINE
*** i. Workspace
*** ii. Cleaning typos & Lables
*** iii. Distance Caluclation (Code written by Gabe T)
*** iv. Saving

NOTES
	Survey form in "//Pakistan Property Tax Project/Analysis/Original Data
		/Inspector Survey/130708 Inspector Phone Survey - Final.docx"
*******************************************************************************/


* i. Workspace
*******************************************************************************************

*** Directory for Gabe - Laptop ***
cap cd "C:/Users/Gabriel/Dropbox/Pakistan Property Tax Project/Analysis"
**********************************

*** Directory for Ben ***
cap cd "C:/Users/bolken/Documents/My Dropbox/Pakistan Property Tax Project/Analysis"
*************************

*** Directory for Obeid ***
cap cd "C:/Users/Obeid/Dropbox/Pakistan Property Tax Project (1)/Analysis"
*************************

*** Directory for Wayne ***
cap cd "C:/Users/wsandhol/Dropbox/Olken/Pakistan Property Tax Project/Analysis"
cap cd "C:/Users/Wayne/Dropbox/Olken/Pakistan Property Tax Project/Analysis"
*************************

clear all
cap log close
set more off
pause on

global analysispath `c(pwd)'
cd ..
global pakistanpath `c(pwd)'
cd "${analysispath}"

ssc install geodist

insheet using "Original Data/Inspector Survey/Inspector Phone Survey.csv", c clear

* ii. Cleaning typos & Lables
********************************************************************************
*** Cleaning some values
drop ins_1 telephonenumbers
drop v42
replace q9 = "KOT RADHA KISHAN" if q9=="1"
replace q8 = "1" if q8=="KOT RADHA KISHAN"
replace q6_d_others="" if q6_d_others == "-"
replace q14_1=. if inlist(q14_1,4,5)
destring q8,replace


*** Setting up Variable lables ans names
label variable q1 "For the whole or most of FY2013 you were posted as inspector in this tax circle"
label variable q2 "In which circle were you posted for FY 2013 if not ONLY in the above-listed circle?"
label variable q3 "How would you score your circle team effort in your duties?"
label variable q4_field "In a typical work day how many hours did you spend in the field"
label variable q4_office "In a typical work day how many hours did you spend in the office"
label variable q5 "How would you describe the pressure from your supervisors for tax collection in the last fiscal year?"
label variable q6_a "Meetings"
label variable q6_b "Visits"
label variable q6_c "Disciplinary Actions"
label variable q6_d "Other"
label variable q6_d_others ""
label variable q7 "Were you ever selected in any ballot in the past two years "
label variable q8 "What scheme were you selected in through the ballot"
label variable q9 "What circle were you balloted for treatment in?"
label variable q10 "Are you still part of this treatment circle/eligible for honorarium payment?"
label variable q11 "How would you rate the level of monitoring during the FY 2012-201?3"
label variable q13 "If there is an additional ballot in July 2013 what chance do you think you may be selected?"
label variable q15 "Right after the ballot in July 2012 did you think there was still a chance that your performance may be rewarded in some manner?"
label variable q16 "How satisfied are you with your current circle posting?"
label variable q12_1 "Level of monitoring you faced compared to Incentive Schemes"
label variable q12_2 "Level of monitoring you faced compared to Information"
label variable q12_3 "Level of monitoring you faced compared to Controls"
label variable q14_1 "Chance compared to Incentive Schemes"
label variable q14_2 "Chance compared to Information"
label variable q14_3 "Chance compared to Controls"
label variable q18_1 "First Choice - Including cities"
label variable q18_2 "Second Choice - Including cities"
label variable q18_3 "Third Choice - Including cities"


label define comparison 1 "Higher" 2 "Same" 3 "Lower"
label values q12* q14* comparison

label define yesno 1 "Yes" 2 "No"
label values q1 q10 yesno

label define pressure 1 "VERY HIGH PRESSURE" 2 "HIGH PRESSURE" 3 "SOME PRESSURE" 4 "LITTLE PRESSURE" 5 "NO PRESSURE AT ALL" 6 "DONT KNOW"
label values q5 pressure

label define ballot 1 "July 2011" 2 "July 2012" 3 "NO"
label values q7 ballot

label define scheme 1 "REVENUE" 2 "REVENUE PLUS" 3 "CFW" 4 "INFORMATION"
label values q8 scheme

label define monitoring 1 "VERY LIGHT MONITORING" 2 "LIGHT MONITORING" 3 "MEDIUM MONITORING" 4 "INTENSE MONITORING" 5 "DONT KNOW"
label values q11 monitoring

label define likely 1 "NOT LIKELY AT ALL (0 chance)" 2 "A BIT LIKELY" 3 "LIKELY (50-50)" 4 "VERY LIKELY" 5 "DEFINITELY (100% chance)" 6 "DONT KNOW"
label values q13 q15 likely

label define satisfaction 1 "VERY UNSATISFIED" 2 "UNSATISFIED" 3 "INDIFFERENT" 4 "SATISFIED" 5 "VERY SATISFIED" 6 "DONT KNOW"
label values q16 satisfaction

label variable q17 "Would you be willing/interested in being posted to a different circle"
label define transfer 1 "Yes" 2 "No" 3 "Indifferent" 4 "Dont Know"
label values q17 transfer


***Renaming Variables

rename q1 postincircle
rename q2 circle_post
rename q3 effort
rename q4_field hrs_field
rename q4_office hrs_office
rename q5 pressure
rename q6_a pres_meet
rename q6_b pres_visit
rename q6_c pres_disc
rename q6_d pres_other
rename q6_d_others pres_other_desc
rename q7 ballot
rename q8 treatment_s
rename q9 circle_ballot
rename q10 eligible
rename q11 monit
rename q12_1 monit_inc
rename q12_2 monit_inf
rename q12_3 monit_con
rename q13 chance
rename q14_1 chance_inc
rename q14_2 chance_inf
rename q14_3 chance_con
rename q15 reward_chance
rename q16 satis
rename status1done2refused3notdone status
rename q17 transfer
rename q18_1 choice_1_
rename q18_2 choice_2_
rename q18_3 choice_3_
encode ifnotdonereason,gen (notdonereason)
order notdonereason,after(ifnotdonereason)
drop ifnotdonereason


**Maunaully cleaning the choices
replace choice_1_ = "107100" if choice_1_ == "CIRCLE I"
replace choice_1_ = "107200" if choice_1_ == "RYK II" 
replace choice_1_ = "615100" if choice_1_ == "GULSHAN RAVI I"
replace choice_2_ = "615200" if choice_2_ == "GULSHAN RAVI II"
replace choice_3_ = "615300" if choice_3_ == "GULSHAN RAVI III"
replace choice_2_ = "107400" if choice_2_ == "RYK IV"
replace choice_3_ = "107600" if choice_3_ == "RYK VI"
replace choice_2_ = "107700" if choice_2_ == "RYK VII"
replace choice_2_ = "300500" if choice_2_ == "BLOCK-X"
replace choice_2_ = "406200" if choice_2_ =="B-II"
replace choice_3_ = "406300" if choice_3_ =="B-XIII"
replace choice_3_ = "307400" if choice_3_ =="JHANG CITY"
replace choice_3_ = "300700" if choice_3_ =="DGLUSPURA"
replace choice_3_ = "401000" if choice_3_ =="PEOPLES COLONY"
replace choice_1_ = "611301" if choice_1_ =="WAPDA TOWN" & division_id==6
replace choice_2_ = "611301" if choice_2_ =="WAPDA TOWN"
replace choice_3_ = "611902" if inlist(choice_3_,"VALANCIA TOWN","VALENCIA TOWN")
replace choice_3_ = "611601" if choice_3_=="CANAL VIEW"
replace choice_1_ = "402900" if choice_1_=="WAPDA TOWN" & division_id==4
replace choice_1_ = "612000,612100" if choice_1_=="MODEL TOWN"
replace choice_2_ = "612000,612100" if choice_2_=="MODEL TOWN"
replace choice_2_ = "610000,610100" if choice_2_=="GARDEN TOWN"
replace choice_2_ = "506502,506501" if choice_2_=="MALIK PARK"
replace choice_2_ = "504301" if choice_2_=="MALL ROAD I"
replace choice_2_ = "500300" if inlist(choice_2_,"G-T.ROAD II","G.T ROAD II")
replace choice_2_ = "609600" if choice_2_=="GULBERG V"
replace choice_2_ = "700100" if choice_2_=="I BLOCK"
replace choice_2_ = "400700" if choice_2_=="SETTELITE TOWN"
replace choice_3_ = "500200" if choice_3_=="SHALIMAR I"
replace choice_3_ = "506600,507600" if choice_3_=="KARIM PARK"
replace choice_3_ = "504500" if choice_3_=="LAWRANCE ROAD"
replace choice_3_ = "612400" if choice_3_=="FAISAL TOWN"
replace choice_3_ = "612300" if choice_3_=="MODEL EXT II"
replace choice_1_ = "1003301,1003302" if choice_1_=="ARIF WALA"
replace choice_1_ = "508000,508800" if choice_1_=="E-WARD"
replace choice_1_ = "610600,610700,611000" if choice_1_=="JOHAR TOWN"
replace choice_3_ = "610600,610700,611000" if choice_3_=="JOHAR TOWN"
replace choice_1_ = "105600,105700" if choice_1_=="HAROON ABAD"
replace choice_1_ = "101200" if choice_1_ == "HASIL PUR"
replace choice_1_ = "302000" if choice_1_ == "SARGODHA ROAD"
replace choice_1_ = "307500" if choice_1_ == "JHANG-II"
replace choice_1_ = "406100" if choice_1_ == "GUJRAT B-I"
replace choice_1_ = "500400" if choice_1_ == "SALAMAT PURA"
replace choice_1_ = "613100" if choice_1_ == "RAIWAND"
replace choice_1_ = "507200,507300" if choice_1_ == "AMIN PARK"
replace choice_1_ = "610600" if choice_1_ == "JOHAAR TOWN I"
replace choice_2_ = "610600" if choice_2_ == "JOHAR TOWN I"
replace choice_3_ = "610600" if choice_3_ == "JOHAR TOWN I"
replace choice_1_ = "503500" if choice_1_ == "ABBAT ROAD"
replace choice_1_ = "700700" if choice_1_ == "IV BLOCK"
replace choice_1_ = "703700" if choice_1_ == "PATTOKI"
replace choice_1_ = "803000" if choice_1_ == "XXII"
replace choice_1_ = "901900" if choice_1_ == "DHJ"
replace choice_1_ = "909800" if choice_1_ == "FATEH JHANG"
replace choice_1_ = "609100" if choice_1_ == "GULBER"
replace choice_1_ = "907102" if choice_1_ == "CIRCLE IV"
replace choice_2_ = "105400,105500" if choice_2_ == "CTN"
replace choice_3_ = "105101,105102,105200" if choice_3_ == "BWN"

split choice_1_ ,p(,) destring force
split choice_2_ ,p(,) destring force
split choice_3_ ,p(,) destring force

label variable choice_1_1 "First Choice 1"
label variable choice_1_2 "First Choice 2"
label variable choice_1_3 "First Choice 3"
label variable choice_2_1 "Second Choice 1"
label variable choice_2_2 "Second Choice 2"
label variable choice_3_1 "Third Choice 1"
label variable choice_3_2 "Third Choice 2"
label variable choice_3_3 "Third Choice 3"

** CLEANING ADDED BY WAYNE, 7 OCTOBER 2013

gen hrs_total = hrs_field + hrs_office
la var hrs_total "Total hours worked in a typical day (field + office)"

** MISSINGS
replace pressure = . if pressure == 6
replace monit = . if monit == 5
replace chance = . if chance == 6
replace satis = . if satis == 6

replace notdonereason = 9 if effort == . & notdonereason == .

** RESCALINGS
gen pressure_scale  = (pressure - 1) / 4
la var pressure_scale "Pressure from supervisors"
gen monit_scale = (monit - 1) / 3
la var monit_scale "Level of monitoring"
gen chance_scale = (chance - 1) / 4
la var chance_scale "Chance you may be selected in next ballot"
gen satis_scale = (satis - 1) / 4
la var satis_scale "How satisfied with current circle posting"

** DUMMIES
gen eligible_dummy = eligible != 2 if !mi(eligible)
la var eligible_dummy "Are you still part of this treatment circle/eligible for hon. payment?"

/* WAS: the dummies with an _s in the middle are dummies for whether the 
	inspector answered the survey question by saying he was in the treatment,
	not whether or not he actually was.  The _s_ is for "survey". */
gen ballot_s_dummy = ballot != 3 if !mi(ballot) & notdonereason == .
la var ballot_s_dummy "Ever selected for treatment (survey)"
gen treatment_s_dummy = !mi(treatment_s) if notdonereason == .
la var treatment_s_dummy "Reports a subtreatment (survey)"
gen rev_s_dummy = treatment_s == 1 if !mi(treatment_s_dummy)
la var rev_s_dummy "Revenue subtreatment (survey)"
gen revplus_s_dummy = treatment_s == 2 if !mi(treatment_s_dummy)
la var revplus_s_dummy "Revenue plus subtreatment (survey)"
gen cfw_s_dummy = treatment_s == 3 if !mi(treatment_s_dummy)
la var cfw_s_dummy "CFW subtreatment (survey)"
gen info_s_dummy = treatment_s == 4 if !mi(treatment_s_dummy)
la var info_s_dummy "Information subtreatment (survey)"

/* WAS: I think the variable subtreatment refers to the treatments actually
	assigned to the inspector */
gen treatment = !mi(subtreatment)
gen rev = subtreatment == "Revenue"
gen revplus = subtreatment == "Revenue PLUS"
gen cfw = subtreatment == "Cond. Fixed Wage"
gen info = subtreatment == "Information"

* iii. Distance
****************************************************************************************************************************

local	r107100	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Bahawalpur/Rahim Yar Khan/RYK 1/RYK I Points"		
local	r107200	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Bahawalpur/Rahim Yar Khan/RYK II/RYK II R3 Edit Points"		
local	r615100	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore B/Zone 9/Gulshan Ravi I/Gulshan Ravi I R3 Edit Points"		
local	r615200	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore B/Zone 9/Gulshan Ravi III/Gulshan Ravi III R3 Edit Points"		
local	r615300	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore B/Zone 9/Gulshan Ravi III/Gulshan Ravi III R3 Edit Points"		
local	r107400	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Bahawalpur/Rahim Yar Khan/RYK IV/RYK IV Points"		
local	r107600	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Bahawalpur/Rahim Yar Khan/RYK VI/RYK VI Points"		
local	r107700	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Bahawalpur/Rahim Yar Khan/RYK VII/RYK VII Points"		
local	r300500	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Faisalabad/Faisalabad City/Block X/Block X R3 Edit Points"		
local	r406200	"${pakistanpath}/Maps/Survey Round 2/Gujranwala/B I, II, II, IV/B I, II, II, IV_Points"		
local	r406300	"${pakistanpath}/Maps/Survey Round 2/Gujranwala/XIII,XIV,XV,XVI,XVII,XIX/XIII,XIV,XV,XVI,XVII,XIX_Points"		
local	r307400	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Faisalabad/Jhang/Jhang City/Jhang City R3 Edit Points"		
local	r300700	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Faisalabad/Faisalabad City/Civil Lines/Civil Line R3 Edit Points"		
local	r401000	"${pakistanpath}/Maps/Survey Round 2/Gujranwala/XXVIII,XXXIII/XXVIII,XXXIII_Points"		
local	r611301	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore B/Extended Area/Valencia Town/Valencia Town R3 Edit Points"		
local	r611902	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore B/Extended Area/Valencia Town/Valencia Town R3 Edit Points"		
local	r611601	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore B/Extended Area/Canal View/Canal View R3 Edit Points"		
local	r402900	"${pakistanpath}/Maps/Survey Round 2/Gujranwala/XXIV,XXX,XXXI,XXXII/XXIV,XXX,XXXI,XXXII_Points"		
local	r612000	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore B/Zone 7/Model Town I/Model Town I R3 Edit Points"		
local	r612100	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore B/Zone 7/Model Town I/Model Town I R3 Edit Points"		
local	r610000	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore B/Zone 6/Garden Town I/Garden Town I R3 Edit Points"		
local	r610100	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore B/Zone 6/Garden Town I/Garden Town I R3 Edit Points"		
local	r506501	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore A/Zone 11/Malik Park I/Malik Park I R3 Edit Points"		
local	r506502	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore A/Zone 11/Malik Park I/Malik Park I R3 Edit Points"		
local	r504301	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore A/Zone 4/Mall Road I/Mall Road I R3 Edit Points"		
local	r500300	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore A/Zone 1/GT Road I/GT Road I R3 Edit Points"		
local	r609600	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore B/Zone 5/Gulberg V/Gulberg V R3 Edit Points"		
local	r700100	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore C/Sheikhpura/Block I & II/Block I & II R3 Edit Points"		
local	r400700	"${pakistanpath}/Maps/Survey Round 2/Gujranwala/XXVIII,XXXIII/XXVIII,XXXIII_Points"		
local	r500200	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore A/Zone 1/GT Road I/GT Road I R3 Edit Points"		
local	r506600	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore A/Zone 11/Karim Park I/Karim Park I R3 Edit Points"		
local	r507600	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore A/Zone 11/Karim Park I/Karim Park I R3 Edit Points"		
local	r504500	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore A/Zone 4/Mall Road I/Mall Road I R3 Edit Points"		
local	r612400	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore B/Model Town Ext/Model Town EXT I/Model Town EXT I R3 Edit Points"		
local	r612300	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore B/Model Town Ext/Model Town EXT II/Model Town EXT II R3 Edit Points"		
local	r1003301	"${pakistanpath}/Maps/Survey Round 1/Sahiwal/Arifwala II/Arifwala II_Points"		
local	r1003302	"${pakistanpath}/Maps/Survey Round 1/Sahiwal/Arifwala II/Arifwala II_Points"		
local	r508000	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore A/Zone 12/E1 Ward/E1 Ward R3 Edit Points"		
local	r508800	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore A/Zone 12/E1 Ward/E1 Ward R3 Edit Points"		
local	r610600	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore B/Extended Area/Canal View/Canal View R3 Edit Points"		
local	r610700	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore B/Extended Area/Canal View/Canal View R3 Edit Points"		
local	r611000	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore B/Extended Area/Canal View/Canal View R3 Edit Points"		
local	r105600	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Bahawalpur/Bahawalnagar/Haroonabad I/Haroonabad 1 Points"		
local	r105700	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Bahawalpur/Bahawalnagar/Haroonabad I/Haroonabad 1 Points"		
local	r101200	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Bahawalpur/Bahawalpur/Hasilpur I,II/Hasilpur I,II Points"		
local	r302000	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Faisalabad/Faisalabad City/Sargodha Road/Sargodha Road R3 Edit Points"		
local	r307500	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Faisalabad/Jhang/Jhang II/Jhang II Points"		
local	r406100	"${pakistanpath}/Maps/Survey Round 2/Gujranwala/Gujrat B 9 16/B 9 & 16 Gujrat_Points"		
local	r500400	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore A/Zone 1/Salamatpura/Salamatpura R3 Edit Points"		
local	r613100	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore B/Extended Area/Valencia Town/Valencia Town R3 Edit Points"		
local	r507200	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore A/Zone 3/Amin Park/Amin Park I R3 Edit points"		
local	r507300	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore A/Zone 3/Amin Park/Amin Park I R3 Edit points"		
local	r503500	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore A/Zone 3/Qilla Gujjar Singh/Qilla Gujjar Singh R3 Edit Points"		
local	r700700	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore C/Sheikhpura/IV, VI, VII, VIII/IV, VI, VII, VIII R3 Edit Points"		
local	r703700	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore C/Kasur/Pattoki/Pattoki R3 Edit Points"		
local	r803000	"${pakistanpath}/Maps/Survey Round 2/Multan/XXII/XXII_Points"		
local	r901900	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Rawalpindi/Rawalpindi/D, H, J/D, H, J R3 Edit Points"		
local	r909800	"${pakistanpath}/Maps/Survey Round 2/Rawalpindi/Fateh Jhang/Fateh Jhang_Points"		
local	r907102	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Rawalpindi/Chakwal/BIV - XIV/BIV - XIV R3 Edit Points"		
local	r609100	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore B/Zone 5/Gulberg V/Gulberg V R3 Edit Points"		
local	r105400	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Bahawalpur/Bahawalnagar/CTN I/Chistian I R3 Edit Points"		
local	r105500	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Bahawalpur/Bahawalnagar/CTN I/Chistian I R3 Edit Points"		
local	r105101	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Bahawalpur/Bahawalnagar/BWN I/BWN I R3 Edit Points"		
local	r105102	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Bahawalpur/Bahawalnagar/BWN I/BWN I R3 Edit Points"		
local	r105200	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Bahawalpur/Bahawalnagar/BWN I/BWN I R3 Edit Points"		
local	r101300	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Bahawalpur/Bahawalpur/Hasilpur I,II/Hasilpur I,II Points"
local	r101800	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Bahawalpur/Bahawalpur/AhmedPur East/Ahmedpur East Points"
local	r105300	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Bahawalpur/Bahawalnagar/Fortabbas/Fortabbas R3 Edit Points"
local	r107300	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Bahawalpur/Rahim Yar Khan/RYK 1/RYK I Points"
local	r203100	"${pakistanpath}/Maps/Survey Round 2/DG Khan/WARD 1-12/WARD 1-12_Points"
local	r205200	"${pakistanpath}/Maps/Survey Round 3/Phase 1/DG Khan/Muzafargrah/Muzaffargarh B/Muzaffargarh B R3 Edit Points"
local	r207400	"${pakistanpath}/Maps/Survey Round 3/Phase 1/DG Khan/Layyah/Karor Laal Eisan/Karor Laal Eisan R3 Edit Points"
local	r300312	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Faisalabad/Faisalabad City/Model Town Islamnagar/Model Town Islamnagar R3 Edit Points"
local	r303302	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Faisalabad/Faisalabad City/Allama Iqbal Colony/Allama Iqbal Colony R3 Edit"
local	r400500	"${pakistanpath}/Maps/Survey Round 2/Gujranwala/XXIV,XXX,XXXI,XXXII/XXIV,XXX,XXXI,XXXII_Points"
local	r406700	"${pakistanpath}/Maps/Survey Round 1/Gujranwala/Gujrat/Kharian/Kharian_Points"
local	r501000	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore A/Zone 1/GT Road I/GT Road I R3 Edit Points"
local	r502700	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore A/Zone 2/Makhanpura I/Makhanpura R3 Edit Points"
local	r504100	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore A/Zone 3/Allama Iqbal Town/Allama Iqbal Town R3 Edit Points"
local	r504200	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore A/Zone 3/Allama Iqbal Town/Allama Iqbal Town R3 Edit Points"
local	r504302	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore A/Zone 4/Mall Road I/Mall Road I R3 Edit Points"
local	r504700	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore A/Zone 4/Mozang/Mozang R3 Edit Points"
local	r506000	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore A/Zone 10/Chohan Road/Chohan Road R3 Edit Points"
local	r507700	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore A/Zone 11/Shadrah Town/Shadrah Town R3 Edit Points"
local	r613200	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore B/Zone 8/Circle II/Circle II R3 Edit Points"
local	r613400	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore B/Zone 8/Circle III/Circle III R3 Edit Points"
local	r614300	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore B/Zone 8/Circle X/Circle X R3 Edit Points"
local	r700500	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore C/Sheikhpura/III, IIIA/III, IIIA R3 Edit Points"
local	r701200	"${pakistanpath}/Maps/Survey Round 1/Lahore C/Muridke II/Muridke II_Points"
local	r701400	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore C/Sheikhpura/Narangmandi/Narangmandi R3 Edit Points"
local	r704600	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore C/Kasur/Chunian/Chunian R3 Edit Points"
local	r704800	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Lahore C/Kasur/Chunian/Chunian R3 Edit Points"
local	r801500	"${pakistanpath}/Maps/Survey Round 2/Multan/IX-III/IX-III_Points"
local	r802700	"${pakistanpath}/Maps/Survey Round 2/Multan/XI-XIII/XI-XIII_Points"
local	r805100	"${pakistanpath}/Maps/Survey Round 2/Multan/Kabirwala/Kabirwala_Points"
local	r809000	"${pakistanpath}/Maps/Survey Round 1/Multan/ABHS/ABHS_Points"
local	r809301	"${pakistanpath}/Maps/Survey Round 1/Multan/ABHS/ABHS_Points"
local	r902901	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Rawalpindi/Rawalpindi/ZB-II/ZB-II R3 Edit Points"
local	r907800	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Rawalpindi/Chakwal/BII, III/BII, III R3 Edit Points"
local	r909600	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Rawalpindi/Attock/Hazro/Hazro R3 Edit Points"
local	r909700	"${pakistanpath}/Maps/Survey Round 3/Phase 1/Rawalpindi/Attock/Pindi Gheb/Pindi Gheb R3 Edit Points"
local	r1000100	"${pakistanpath}/Maps/Survey Round 2/Sahiwal/Block VI, VI-A(Two circles)/Block VI, VI-A(Two circles)_Points"
local	r1000300	"${pakistanpath}/Maps/Survey Round 2/Sahiwal/Block VI, VI-A(Two circles)/Block VI, VI-A(Two circles)_Points"
local	r1000600	"${pakistanpath}/Maps/Survey Round 1/Sahiwal/Arifwala II/Arifwala II_Points"
local	r1001200	"${pakistanpath}/Maps/Survey Round 1/Sahiwal/Arifwala II/Arifwala II_Points"
local	r1005300	"${pakistanpath}/Maps/Survey Round 2/Sahiwal/Okara I/Okara I_Points"
local	r1101700	"${pakistanpath}/Maps/Survey Round 2/Sargodha/Bhera/Bhera_Points"


#delimit ;
global circ_list
"107100
107200
615100
615200
615300
107400
107600
107700
300500
406200
406300
307400
300700
401000
611301
611902
611601
402900
612000
612100
610000
610100
506501
506502
504301
500300
609600
700100
400700
500200
506600
507600
504500
612400
612300
1003301
1003302
508000
508800
610600
610700
611000
105600
105700
101200
302000
307500
406100
500400
613100
507200
507300
503500
700700
703700
803000
901900
909800
907102
609100
105400
105500
105101
105102
105200
101300
101800
105300
107300
203100
205200
207400
300312
303302
400500
406700
501000
502700
504100
504200
504302
504700
506000
507700
613200
613400
614300
700500
701200
701400
704600
704800
801500
802700
805100
809000
809301
902901
907800
909600
909700
1000100
1000300
1000600
1001200
1005300
1101700";
#delimit cr


foreach circ in $circ_list{
di `circ'
preserve
insheet using "`r`circ''.csv", clear

			cap ren e xcoord
			cap ren n ycoord
			cap ren N ycoord
			cap ren E xcoord
			recast double xcoord ycoord
			count
			local max = r(N)
			g n = _n
			tostring n,replace
			g _point = "S"+n
			drop n
			cap drop type
			cap drop point
			cap drop idno
			cap drop id
			cap drop Point
			cap drop Type
			gen circle_id=`circ'
			reshape wide xcoord ycoord,i(circle_id) j(_point) string
			
			forval i = 1/3{
			forval j = 1/3{
			g choice_`i'_`j' = circle_id
			}
			}
			tempfile c`circ'choice
			sa `c`circ'choice'
			
			drop choice*
			tempfile c`circ'
			sa `c`circ''
			di `circ'
			ta xcoordS1
			
			gen max = `max'
			keep max circle_id
			tempfile p`circ'
			sa `p`circ''
restore
}


tempfile main
sa `main'
clear
foreach circ in $circ_list{
di `circ'
append using `c`circ''
}
merge 1:1 circle_id using `main'
assert _merge!=1
drop _merge

/*
clear
foreach circ in `circ_list'{
append using `p`circ''
}
*/

#delimit ;
local choosers
"101300
105300
107100
107200
107300
300312
303302
400500
406700
501000
502700
504100
504200
504302
506000
506501
506600
507700
613200
613400
614300
700500
704800
801500
902901
907800
909700
1001200";
#delimit cr

tempfile full
sa `full'

keep if choice_1_1!=. |choice_1_2!=.| choice_1_3!=.| choice_2_1!=.| choice_2_2!=.| choice_3_1!=.| choice_3_2!=.| choice_3_3!=.
local choice_list "choice_1_1 choice_1_2 choice_1_3 choice_2_1 choice_2_2 choice_3_1 choice_3_2 choice_3_3"

tempfile red
sa `red'

foreach sel in `choosers'{
u `red',clear
di `sel'
keep if circle_id==`sel'

foreach choice in `choice_list'{
gen `choice'_dist=.


sum `choice' if circle_id==`sel'
cap local circ2 = `r(mean)'
cap di `circ2'



if `choice'!=.{
	preserve
		use `c`circ2'choice',clear
		ren xcoord* zxcoord*
		ren ycoord* zycoord*
		tempfile z`circ2'
		sa `z`circ2''
	restore
	merge 1:1 `choice' using `z`circ2''
	count if _merge==3
	drop _merge
	assert r(N)==1
	forval i = 1/100{
		cap geodist xcoordS`i' ycoordS`i' zxcoordS`i' zycoordS`i',gen(temp_dist_`i')
	}
	egen `choice'_dist_temp = rowmean(temp_dist*)
	replace `choice'_dist = `choice'_dist_temp
	drop *temp* z*
	}
			
}
tempfile `sel'set
sa ``sel'set'
}

clear
foreach sel in `choosers'{
append using ``sel'set'
}



tempfile choices
sa `choices'
u `full',clear
drop if choice_1_1!=. |choice_1_2!=.| choice_1_3!=.| choice_2_1!=.| choice_2_2!=.| choice_3_1!=.| choice_3_2!=.| choice_3_3!=.
append using `choices'

drop xcoord* ycoord*

* iv. Saving
******************************************************************************************************************************************

saveold "Original Data/Inspector Survey/Inspector Survey Clean.dta",replace
