/*******************************************************************************
CLEANING SURVEY ROUND 3

Wayne Aaron Sandholtz
27 August 2013

Obeid Rehman
21 January 2014

Kunal Mangal
1 January 2015

SUMMARY: Cleans section by section for the compiled files generated by Unencrypt and Compile.do.
		 Data goes from the Compiled folder to the Cleaned folder.
		 
		 Lastly merge all the sections together into a compiled file, add treatment
		 variables and clusters.

OUTLINE:
	1. Code missing values and other aberrations
	2. Otherwise prepare data for analysis
NOTES:
	- This file uses the saveold command, which seems to be the only way
		a dataset produced by Stata 13 can be read by Stata <=12
*******************************************************************************/

/* Note from Obeid.
	Also I was just going through some of the cleaning do files, one thing I 
	thought to mention when your looking at missings just check that the question 
	is in both the long and short survey, Otherwise if the question is only in the 
	long for example then alot of missings will show up
*/

clear all
set more off

cap cd "${PAKTAX_ANALYSIS}"
cap mkdir "Data/Cleaned Data/Field Survey/Round 3/Cleaned"

cap progaram drop cleanmissings
program define cleanmissings
	syntax [, IGNORElist(varlist)]
	
	if "`ignorelist'" != "" qui ds `ignorelist', not
	if "`ignorelist'" == "" qui ds, not(type string)
	foreach var of varlist `r(varlist)'{
		cap confirm numeric variable `var'
		if !_rc {
			* -99, -50
			qui count if `var' == -99 | `var' == -50
			if `r(N)' != 0{
				tab `var' if `var' == -99 | `var' == -50
				di "`var' `: var l `var''"
				qui replace `var' = . if `var' == -99 ///
					| `var' == -50
				}
				
			** 9999, 9998
			qui count if `var' == 9999 | `var' == 9998 
			if `r(N)' != 0{
				tab `var' if `var' == 9999 | `var' == 9998 
				di "`var' `: var l `var''"
				replace `var' = .a if `var' == 9999 // Don't know
				replace `var' = .b if `var' == 9998 // No change
			}		
		}
	}
end

*********************************************************************************
*********************************************************************************
*********************************************************************************

* I. GO SECTION BY SECTION AND CLEAN

******************************************
* Backmatch

u "Data/Cleaned Data/Field Survey/Round 3/Compiled/Backmatch.dta", clear
cleanmissings, ignorelist("BM_q22 BM_q23")

** FIX MISLABELED THINGS
la var BM_q29 "If the property has been reassessed after June 31st 2011?"

* RENAME VARS
ren BM_q19 category
replace category = upper(category)

renpfix BM_q18a_ BM_cov_area
renpfix BM_q18b_ BM_cov_area_un
renpfix BM_q18c_ BM_cov_area_typ
ren BM_q17a BM_land_area
ren BM_q17b BM_land_area_un
ren BM_q20 BM_floors
ren BM_q21 BM_main_road
ren BM_q22 BM_GARV
ren BM_q27a BM_tax_last_payment

* CLEAN EXEMPTIONS
replace BM_q26=. if BM_q26==9    // 9 means no exemptions same as missing

* CLEAN LAND AREA
*replace BM_land_area = "" if regexm(BM_land_area,"/|\-")
replace BM_land_area = trim(BM_land_area)
replace BM_land_area = "2.266" if BM_land_area == "2/60" 
replace BM_land_area = "1.4" if BM_land_area == "1/90" 
replace BM_land_area = "3.155" if BM_land_area == "3/35"
replace BM_land_area_un = 5 if BM_land_area == "2,2"
replace BM_land_area = "2" if BM_land_area == "2,2"
replace BM_land_area_un = 5 if BM_land_area == "6/2"
replace BM_land_area = "3" if BM_land_area == "6/2"
replace BM_land_area = "6.18" if BM_land_area == "6-50"
replace BM_land_area = regexr(BM_land_area,",",".")
replace BM_land_area = "70" if BM_land_area=="70 Y"
replace BM_land_area = "200" if BM_land_area=="200Y"
replace BM_land_area = "1" if BM_land_area=="222F"
destring BM_land_area, replace

* CLEAN TAX LIABILITY
rename BM_q25 BM_tax_liability
replace BM_tax_liability = "4995" if BM_tax_liability == "A-23696,29700"
replace BM_tax_liability = "829" if BM_tax_liability == "829/60"
replace BM_tax_liability = "378" if BM_tax_liability == "37/8"
replace BM_tax_liability = "2924" if BM_tax_liability == "2924/40"
replace BM_tax_liability = "310" if BM_tax_liability == "3/0"
replace BM_tax_liability = "1266" if BM_tax_liability == "1152-P/1266"
replace BM_tax_liability = "2016" if BM_tax_liability == "22/6"
replace BM_tax_liability = "618" if prop_id == "09005000305"
replace BM_tax_liability = "457" if prop_id == "09005000401"
replace BM_tax_liability = "552" if prop_id == "09005000402"
replace BM_tax_liability = "466" if prop_id == "09005000403"
replace BM_tax_liability = "17595" if prop_id == "09005000407"
replace BM_tax_liability = "233" if regexm(BM_tax_liability, "C")
*replace BM_tax_liability = "" if regexm(BM_tax_liability, "-")
*replace BM_tax_liability = "" if regexm(BM_tax_liability, "/")
destring BM_tax_liability, replace

*CLEAN MAIN ROAD OFF ROAD
replace BM_main_road="MAIN" if inlist(BM_main_road,"M/R","MAIN ROAD")
replace BM_main_road="OFF" if inlist(BM_main_road,"OFF ROAD")
//Should just encode here if we need this variable for anything

* CLEAN GARV
replace BM_GARV = 19777  if prop_id=="01001000702"
replace BM_GARV = 39000  if prop_id=="01013000106"
replace BM_GARV = 4539   if prop_id=="01052000608"
replace BM_GARV = 41755  if prop_id=="01054000205"
replace BM_GARV = 4800   if prop_id=="01055000307"
replace BM_GARV = 42000  if prop_id=="01055000701"
replace BM_GARV = 18492  if prop_id=="01075000105"
replace BM_GARV = 14111  if prop_id=="01076000103"
replace BM_GARV = 2111   if prop_id=="01081020506"
replace BM_GARV = 6300   if prop_id=="03037002001"
replace BM_GARV = 7800   if prop_id=="06121000409"
replace BM_GARV = 6300   if prop_id=="06120000404"
replace BM_GARV = 44346  if prop_id=="06129000307"
replace BM_GARV = 61800  if prop_id=="06121000405"
replace BM_GARV = 14760  if prop_id=="01071000303"
replace BM_GARV = 362    if prop_id=="02071001104"
replace BM_GARV = 27240  if prop_id=="03031000203"
replace BM_GARV = 37382  if prop_id=="05080000904"
replace BM_GARV = 15720  if prop_id=="03072000206"
replace BM_GARV = 27230  if prop_id=="05043010201"
replace BM_GARV = 12466  if prop_id=="06115000507"
replace BM_GARV = 240102 if prop_id=="03003110103"

preserve
	insheet using "Data/Raw Data/Survey Data/BM_GARV_corr.csv",clear
	keep prop_id bm_garv_corr bm_q23_corr cleaned
	keep if cleaned==1
	sort prop_id
	format prop_id %15.0f
	rename prop_id prop_id_new
	tempfile garv_corr
	sa `garv_corr'
restore

gen prop_id_new=prop_id
destring prop_id_new,replace
merge 1:1 prop_id_new using `garv_corr'
replace BM_q23=bm_q23_corr if bm_q23_corr!=. 
replace BM_GARV=bm_garv_corr if bm_garv_corr!=. 
drop bm_garv_corr bm_q23_corr cleaned prop_id_new _merge

* CREATE VARIABLES FOR CHECKING ACCURACY 
gen BM_match = BM_q13 == 1
la var BM_match "Could the property be located on the official tax rolls?"

gen reassessed = BM_q29 == 1 if BM_q29 !=.
la var reassessed "Was property re-assessed since July 2011?"

* Tax Paid? 
gen notpaid = (BM_tax_last_payment == 0) if BM_tax_liability > 0

saveold "Data/Cleaned Data/Field Survey/Round 3/Cleaned/Backmatch.dta", replace

******************************************
* Log Section 1

u "Data/Cleaned Data/Field Survey/Round 3/Compiled/Log_Sec1.dta", clear
cleanmissings
	
saveold "Data/Cleaned Data/Field Survey/Round 3/Cleaned/Log_Sec1.dta", replace

******************************************
* Log Section 2

u "Data/Cleaned Data/Field Survey/Round 3/Compiled/Log_Sec2.dta", clear
cleanmissings

foreach var of varlist LS2_q14 {
	replace `var' = .a if `var' == 999
	replace `var' = .a if `var' == 99 // don't know
	}
	
saveold "Data/Cleaned Data/Field Survey/Round 3/Cleaned/Log_Sec2.dta", replace

******************************************
* SEC9 Log

u "Data/Cleaned Data/Field Survey/Round 3/Compiled/SEC9_Log.dta", clear

cleanmissings

* Clean dates
*-------------------------------------------

* Date Added
* Row 1

replace S9LOG_q2_1 = "31/12/2012" if inlist(S9LOG_q2_1, "12/31/2012", "31/12/12", "31/12/012")
replace S9LOG_q2_1 = "30/6/2012" if S9LOG_q2_1 == "6/30/2012"
replace S9LOG_q2_1 = "30/6/2013" if inlist(S9LOG_q2_1, "6/30/2013", "30-06-2013")

replace S9LOG_q2_1 = "04/12/2012" if S9LOG_q2_1 == "04/12/2201"
replace S9LOG_q2_1 = "30/01/2012" if S9LOG_q2_1 == "30/01/2201"
replace S9LOG_q2_1 = "30/06/2013" if S9LOG_q2_1 == "30/06/2501"

replace S9LOG_q2_1 = "30/12/2012" if S9LOG_q2_1 == "30/12/012"

gen register_added_date_1 = date(S9LOG_q2_1, "DMY")
format register_added_date_1 %td

drop S9LOG_q2_1

* Row 2
replace S9LOG_q2_2 = "" if S9LOG_q2_2 == "/  /"
replace S9LOG_q2_2 = "" if S9LOG_q2_2 == "."

split S9LOG_q2_2, p("/")

gen register_added_year_2 = ""
replace register_added_year_2 = S9LOG_q2_21 if S9LOG_q2_22 == ""
replace register_added_year_2 = S9LOG_q2_23 if S9LOG_q2_22 != ""
destring register_added_year_2, replace

drop S9LOG_q2_2 S9LOG_q2_21 S9LOG_q2_22 S9LOG_q2_23

* Row 3
replace S9LOG_q2_3 = "" if S9LOG_q2_3 == "-  -"
replace S9LOG_q2_3 = "" if S9LOG_q2_3 == "/  /"
replace S9LOG_q2_3 = "" if S9LOG_q2_3 == "."

gen register_added_year_3 = S9LOG_q2_3
destring register_added_year_3, replace

drop S9LOG_q2_3

* Tax liable Date

* Row 1
replace S9LOG_q3_1 = "01/01/2013" if S9LOG_q3_1 == "01/01/13"
replace S9LOG_q3_1 = "01/07/2012" if S9LOG_q3_1 == "00/72/012"

gen tax_liable_date_1 = date(S9LOG_q3_1, "DMY")
format tax_liable_date_1 %td

drop S9LOG_q3_1

* Row 2
replace S9LOG_q3_2 = "" if S9LOG_q3_2 == "/  /"
replace S9LOG_q3_2 = "" if S9LOG_q3_2 == "."

split S9LOG_q3_2, p("/")

gen tax_liable_year_2 = ""
replace tax_liable_year_2 = S9LOG_q3_21 if S9LOG_q3_22 == ""
replace tax_liable_year_2 = S9LOG_q3_23 if S9LOG_q3_22 != ""
destring tax_liable_year_2, replace

drop S9LOG_q3_2 S9LOG_q3_21 S9LOG_q3_22 S9LOG_q3_23

* Row 3
replace S9LOG_q3_3 = "" if S9LOG_q3_3 == "-  -"
replace S9LOG_q3_3 = "" if S9LOG_q3_3 == "/  /"
replace S9LOG_q3_3 = "" if S9LOG_q3_3 == "."

replace S9LOG_q3_3 = "2003" if S9LOG_q3_3 == "01/01/2003"

gen tax_liable_year_3 = S9LOG_q3_3
destring tax_liable_year_3, replace

order register_added_date_1 tax_liable_date_1, after(row_no_1)

forval i = 2/3 {
	order register_added_year_`i' tax_liable_year_`i', after(row_no_`i')
}

* Tax Paid?
gen notpaid = (S9LOG_q17a_1 == 0) if S9LOG_q16_1 > 0

* Clean and standardize area
*-------------------------------------------

** Covered Area
forv i = 1/3{
	rename S9LOG_q7_`i'_1 BM_cov_area`i'
	rename S9LOG_q8_`i'_1 BM_cov_area_un`i'
	rename S9LOG_q9_`i'_1 BM_cov_area_typ`i'
	}

** Land Area
rename S9LOG_q6a_1 BM_land_area
rename S9LOG_q6b_1 BM_land_area_un

** GARV.
rename S9LOG_q13_1 BM_GARV 

** Other.
rename S9LOG_q16_1 BM_tax_liability
rename S9LOG_q11_1 BM_floors
rename S9LOG_q12_1 BM_main_road
rename S9LOG_q10_1 category 
replace category = upper(category)

saveold "Data/Cleaned Data/Field Survey/Round 3/Cleaned/SEC9_Log.dta", replace

******************************************
* SEC9 Title

u "Data/Cleaned Data/Field Survey/Round 3/Compiled/SEC9_Title.dta", clear
cleanmissings

** CHANGE JUNE 31 TO JULY 1
gen dateflag = 1 if T_q7_int_month == 6 & T_q7_int_day == 31
replace T_q7_int_month = 7 if dateflag == 1
replace T_q7_int_day = 1 if dateflag == 1
drop dateflag
gen surveydate = mdy(T_q7_int_month,T_q7_int_day,T_q7_int_y + 2000)
format surveydate %td

saveold "Data/Cleaned Data/Field Survey/Round 3/Cleaned/SEC9_Title.dta", replace

******************************************
* SEC9 Title Count

u "Data/Cleaned Data/Field Survey/Round 3/Compiled/SEC9_Title_Count.dta", clear
cleanmissings
saveold "Data/Cleaned Data/Field Survey/Round 3/Cleaned/SEC9_Title_Count.dta", replace

******************************************
* Section 1

u "Data/Cleaned Data/Field Survey/Round 3/Compiled/Section 1.dta", clear
cleanmissings

foreach var of varlist SEC1_q12 {
	replace `var' = .a if `var' == 999
	replace `var' = .a if `var' == 99 // don't know
	}
	
** AGE
ren SEC1_q12 age

** GENDER
gen male = SEC1_q1 == 1 if SEC1_q1 != .
la var male "0 = female, 1 = male"

** YEARS OF EDUCATION
gen educ_yrs = SEC1_q14
replace educ_yrs = 12 if SEC1_q14 == 11
replace educ_yrs = 16 if SEC1_q14 == 12
replace educ_yrs = 18 if SEC1_q14 == 13
replace educ_yrs = . if SEC1_q14 == 14
replace educ_yrs = 0 if SEC1_q14 > 14
la var educ_yrs "Years of formal education"

** WIDOW
gen widow = SEC1_q15 == 7 if !missing(SEC1_q15)

save "Data/Cleaned Data/Field Survey/Round 3/Cleaned/Section 1.dta", replace

******************************************
* Section 2

u "Data/Cleaned Data/Field Survey/Round 3/Compiled/Section 2.dta", clear
cleanmissings

foreach var of varlist SEC2_q2a SEC2_q3a {
	replace `var' = . if `var' == 999
	replace `var' = . if `var' == 99 // don't know
	}
	
	
** RESCALE: 0 to 1 - corruption, service, satisfaction

foreach var in SEC2_q1c* SEC2_q2c* SEC2_q3c* SEC2_q1d* SEC2_q2d* SEC2_q3d* {
		recode `var' (1 = 0) ///
					(2 = 0.25) ///
					(3 = 0.5) ///
					(4 = 0.75) ///
					(5 = 1)
	label values `var'
	}
	
la var SEC2_q1c_2 "In July13-Date,quality of service offered by electricity department"
la var SEC2_q1d_2 "How satisfied with members of electricity department in July13-Date"
la var SEC2_q2c_2 "In July13-Date,quality of service offered by Property Tax department"
la var SEC2_q2d_2 "How satisfied with members of Property Tax department in July13-Date"
la var SEC2_q3c_2 "In July13-Date,quality of service offered by Water & Sanitation department"
la var SEC2_q3d_2 "How satisfied with members of Water & Sanitation department in July13-Date"	

** CUSTOMER SATISFACTION
ren SEC2_q1c elec_quality
ren SEC2_q2c tax_quality
ren SEC2_q3c water_quality
ren SEC2_q1d elec_satisfied
ren SEC2_q2d tax_satisfied
ren SEC2_q3d water_satisfied
	
** LIST EXPERIMENT
gen card1 = SEC2_q4a == 1 if short_section2 != 1
la var card1 "Card 1 (more options)"
gen card2 = SEC2_q4a == 2 if short_section2 != 1
la var card2 "Card 2 (fewer options)"
gen activities_card1 = SEC2_q4b if SEC2_q4a == 1
la var activities_card1 "SEC2_q4b if SEC2_q4a == 1"
gen activities_card2 = SEC2_q4b if SEC2_q4a == 2
la var activities_card2 "SEC2_q4b if SEC2_q4a == 2"
gen payments_card1 = SEC2_q4c if SEC2_q4a == 1
la var payments_card1 "SEC2_q4c if SEC2_q4a == 1"
gen payments_card2 = SEC2_q4c if SEC2_q4a == 2
la var payments_card2 "SEC2_q4c if SEC2_q4a == 2"

saveold "Data/Cleaned Data/Field Survey/Round 3/Cleaned/Section 2.dta", replace

******************************************
* Section 3

u "Data/Cleaned Data/Field Survey/Round 3/Compiled/Section 3.dta", clear
cleanmissings

foreach var of varlist SEC3_q2a SEC3_q2b SEC3_q4a SEC3_q4b SEC3_q10b_1 SEC3_q10b_2 ///
	SEC3_q11a_2 SEC3_q11b_2 SEC3_q13c SEC3_q4a_1 SEC3_q4a_2 SEC3_q4a_3 ///
	SEC3_q4a_4 SEC3_q4b_1 SEC3_q4b_2 SEC3_q4b_3 SEC3_q4b_4 {
	replace `var' = . if `var' == 999
	replace `var' = . if `var' == 99 // don't know
	}
	
forv i = 1/2{
	local x: word `i' of "elec" "tax"
	local y: word `i' of "a" "b"

** CORRUPTION
	la var SEC3_q2`y' "Times per year make an unofficial payment to the `x' department?"
	
	gen `x'_unofficial_payment = SEC3_q1`y' == 1 if SEC3_q1`y' != .
	forv j = 1/8{
		local desc: word `j' of label define purpose_payment "Reduce bill" "Settle a dispute" "Obtain speedier service"  ///
			"Obtain a new connection" "Fix broken service" "Obtain a permission to expand property" "Change use of property" "Other" 
		gen `x'_purpose_payment_`j' = SEC3_q3`y'_1 == `j' if SEC3_q3`y'_1 != .
		replace `x'_purpose_payment_`j' = 1 if SEC3_q3`y'_2 == `j' | ///
			SEC3_q3`y'_3 == `j' | SEC3_q3`y'_4 == `j'
		la var `x'_purpose_payment_`j' "Purpose of payment to `x' dept is `desc'" 
		}
	forv j = 1/2{
		local h: word `j' of "person_dept" "prop_owner" 
		gen `x'_suggest_`h' = SEC3_q5`y' == `i' if SEC3_q5`y' != .
		la var `x'_suggest_`h' "`j' suggests the payment in `x' dept"
		local g: word `j' of "fixed" "negotiable"
		gen `x'_payment_`g' = SEC3_q6`y' == `i' if SEC3_q6`y' != .
		}
	forv j = 1/3{
		local f: word `j' of "higher" "same" "lower"
		gen `x'_payments_`f' = SEC3_q8`y' == `j' if SEC3_q8`y' != .
		la var `x'_payments_`f' "Payments to `x' dept `f' compared to last year"
		}
	forv j = 1/4{
		local u: word `j' of "floors" "multi_story" "other" "no_change"
		cap gen `x'_priority_`u' = SEC3_q9b == `j' if SEC3_q9b != .
		cap la var `x'_priority_`u' "Priority is `u'"
		}
	gen `x'_payment_for_improvements = SEC3_q11`y'_1 == 1 if SEC3_q11`y'_1 != .
	// HOW DO MISSINGS DIFFER FROM ZEROS?
	forv b = 1/4{
		gen `x'_unofficial_payment_short`b' = SEC3_q4`y'_`b' ///
			if SEC3_q4`y'_`b' >= 0
		}
	egen `x'_payment_total = rowmean(`x'_unofficial_payment_short?) ///
		if short_section3 == 1
	replace `x'_payment_total = SEC3_q4`y' if SEC3_q4`y' >= 0 & short_section3 != 1
	la var `x'_payment_total "Total annual unofficial payments to `x' dept"
	}

** RESCALE: 0 to 1 - corruption, service, satisfaction

foreach var in SEC3_q12b* SEC3_q12a* SEC3_q12c*{
		recode `var' (1 = 0) ///
					(2 = 0.25) ///
					(3 = 0.5) ///
					(4 = 0.75) ///
					(5 = 1)
	label values `var'
	}

** RESCALE: -1 to 1 - payments higher or lower than last year.
foreach var in SEC3_q8a SEC3_q8b{
	recode `var'	(1 = 1) ///
					(2 = 0) ///
					(3 = -1)
	label values `var'
	}
	
la var SEC3_q8a "Unofficial pmts to elec dept compared to last year"
la var SEC3_q8b "Unofficial pmts to tax dept compared to last year"

la var SEC3_q2b_1 "Owner made per year unofficial payment to Property Tax Dept : July13-Date"
la var SEC3_q4b_1 "Unofficial payment to Property Tax Dept over entire year : July13-Date?"
la var SEC3_q8b_1 "In July13-Date, unofficial payments to person from Property Tax Dept are...?"
la var SEC3_q12a_1 "In July13-Date, degree of corruption involving of Electricity Dept?"
la var SEC3_q12b_1 "In July13-Date, degree of corruption involving of Property Tax Dept?"
la var SEC3_q12c_1 "In July13-Date, degree of corruption involving of Water & Sanitation Dept?"

** RENAMES (TO SIMPLIFY REGRESSION CODE WHEN CONTROLLING FOR ELEC VARS)
ren SEC3_q2b		tax_times_payment
ren SEC3_q2a		elec_times_payment
ren SEC3_q4b		tax_payment_purposes
ren SEC3_q4a		elec_payment_purposes
ren SEC3_q7b		tax_pct_negotiate
ren SEC3_q7a		elec_pct_negotiate
ren SEC3_q11b_1		tax_pay_person
ren SEC3_q11a_1		elec_pay_person
ren SEC3_q11b_2		tax_amt_person
ren SEC3_q11a_2		elec_amt_person
ren SEC3_q12b		tax_corruption
ren SEC3_q12a		elec_corruption
ren SEC3_q12c		water_corruption
ren SEC3_q13b		tax_goingrate
ren SEC3_q13a		elec_goingrate
ren SEC3_q8b		tax_pmt_compare
ren SEC3_q8a 		elec_pmt_compare

saveold "Data/Cleaned Data/Field Survey/Round 3/Cleaned/Section 3.dta", replace


******************************************
* Section 4

/* There were a few wacky dates -- people who put their last tax payment in the 
future, e.g. -- and this is Obeid's file correcting those errors.  Here we just
turn it into a .dta; we'll bring it back shortly to actually make the changes.*/

insheet using "Data/Raw Data/Survey Data/sec4_q16_and_21b_errors.csv", clear
rename circle_code circle_id
saveold "Data/Raw Data/Survey Data/sec4_q16_and_21b_errors.dta", replace

u "Data/Cleaned Data/Field Survey/Round 3/Compiled/Section 4.dta", clear
cleanmissings

// before independence
replace SEC4_q1 = 1947 if SEC4_q1 == 88 

foreach var of varlist SEC4_q1 SEC4_q12a SEC4_q21b*  {
	replace `var' = . if `var' == 999
	replace `var' = . if `var' == 99 // don't know
	}
	
la var SEC4_q13a_2 "Did you/your property owner receive : Demand/Chalan July 2013 to date"
la var SEC4_q24_1_1 "How many time in July13 - Date has someone from Electricity Dept visited propert"
la var SEC4_q24_1_2 "How many time in July13 - Date has someone from Property Tax Dept visited proper"


** FIX MISLABELED THINGS
la var SEC4_q26 ///
	"How much pay for last payment b/w JULY 2011 and JUNE 2012: Property Tax Dept?"
label define SEC4_q12a_labels 1 "A" 2 "B" 3 "C" 4 "D" 5 "E" 6 "F" 7 ///
	"G" 99 "Don't Know"
label values SEC4_q12a SEC4_q12a_labels
label define yearly_labels 1 "Monthly" 2 "Quarterly" 3 "Yearly"
label define working 1 "Daily" 2 "Several times a week" 3 "Once a week" 4 "Several times a month" 5 "Monthly" 6 "Several times a year" 7 "Once a year" 9 "Never" 8 "Never", replace
label define purpose_payment 1 "Reduce bill" 2 "Settle a dispute" 3 "Obtain speedier service" 4 "Obtain a new connection" 5 "Fix broken service" 6 "Obtain a permission to expand property" 7 "Change use of property" 8 "Other", replace

label values SEC4_q27 yearly_labels
label values SEC4_q30 yearly_labels

** YEARS OCCUPYING CURRENT PROPERTY
la var SEC4_q1 "Since which year have you been an occupant of this property?"

** FIX PEOPLE WHO SUPPOSEDLY MADE THEIR LAST PAYMENT IN THE FUTURE
merge m:1 circle_id cluster_id prop_no ///
	using "Data/Raw Data/Survey Data/sec4_q16_and_21b_errors.dta"
	
replace SEC4_q16b_month_1 = q16_present_month_2 if _merge == 3
replace SEC4_q16b_year_1 = q16_present_year_2 if _merge == 3
replace SEC4_q21b_month_2 = q21b_month_2 if _merge == 3
replace SEC4_q21b_year_2 = q21b_year_2 if _merge == 3

drop id q* _merge

* TAX AND ELECTRICITY STUFF

* Fix data entry errors in payment coding
tostring SEC4_q20_2b, gen(SEC4_q20_2b_check)
replace SEC4_q20_2b = 1 if substr(SEC4_q20_2b_check, 1, 1) == "1" & SEC4_q20_2b > 2 // values should be 1 or 2, so larger values that start with 1 are data entry errors
drop SEC4_q20_2b_check

* TAX PAYMENT 13-14
gen tax_last_payment_1314 = SEC4_q13b_2a_2
replace tax_last_payment_1314 = SEC4_q13b_2c_2 if SEC4_q13b_2b_2==2
replace tax_last_payment_1314 = 0 if SEC4_q13a_2 == 2
replace tax_last_payment_1314 = 0 if SEC4_q13b1_2 == 2

* TAX PAYMENT 12-13
gen tax_last_payment = SEC4_q20_2a if SEC4_q20_2b == 1
replace tax_last_payment = SEC4_q20_2c if SEC4_q20_2b == 2
replace tax_last_payment = 0 if SEC4_q13_2 == 2 & phase == 2 // new skip pattern in phase 2
replace tax_last_payment = 0 if SEC4_q19_2 == 2

la var tax_last_payment "Total tax payment, 2012-2013"

* TAX PAYMENT 11-12
gen tax_last_payment_1112 = SEC4_q26 if inlist(SEC4_q25, 1, 2) | short_section4 == 1
replace tax_last_payment_1112 = 0 if SEC4_q25 == 3 

* TAX PAYMENT 10-11
gen tax_last_payment_1011 = SEC4_q29 if inlist(SEC4_q28, 1, 2) | short_section4 == 1
la var tax_last_payment_1011 "Total last payment in 2010/2011"
replace tax_last_payment_1011 = 0 if SEC4_q28 == 3

gen tax_pay_1011 = SEC4_q25 < 3 if !mi(SEC4_q25)
la var tax_pay_1011 "Did you pay for this property in 2010-2011?"

forv i = 1/2{
	local x: word `i' of "elec" "tax"
	local y: word `i' of "a" "b"
	gen `x'_pay = SEC4_q19_`i' == 1 if SEC4_q19_`i' != .
	la var `x'_pay "Binary: did you pay `x' bill"
	gen `x'_lasttime = mdy(SEC4_q21b_month_`i',1,SEC4_q21b_year_`i' + 2000) ///
		if SEC4_q21b_month_`i' != 99 & SEC4_q21b_year_`i' != 99
	la var `x'_lasttime "Date of last `x' payment"

	gen `x'_paydirect = SEC4_q22_`i' == 2 if SEC4_q22_`i' != .
	la var `x'_paydirect "Paid `x' directly to dept. individual"
}


** DUMMY FOR MULTIPLE USE
gen multiple_use = SEC4_q3a == 1 if SEC4_q3a != .
la var multiple_use "Multiple use dummy"

** SEPARATE DUMMIES FOR LAST RENOVATION IN PAST 1,2,3 YEARS
forv i = 1/3{
	gen last_renovation`i' = 2013 - SEC4_q10 < `i' + 1 if SEC4_q10 < 9998
	replace last_renovation`i' = 0 if missing(SEC4_q10)
	la var last_renovation`i' "Last renovation was <= `i' years ago"
	}

** RENAMES (TO SIMPLIFY REGRESSION CODE WHEN CONTROLLING FOR ELEC VARS)
ren SEC4_q20_1		elec_last_payment
ren SEC4_q24_2		tax_times_visit
ren SEC4_q24_1		elec_times_visit

saveold "Data/Cleaned Data/Field Survey/Round 3/Cleaned/Section 4.dta", replace


******************************************
* Section 5

u "Data/Cleaned Data/Field Survey/Round 3/Compiled/Section 5.dta", clear
cleanmissings

** HOUSEHOLD NETWORKS

foreach var in political officer police_army{
	gen connect_`var' = SEC5_q2_`var' == 1 ///
		& !inlist(7, SEC5_q3_1_`var', SEC5_q3_2_`var', SEC5_q3_3_`var', ///
			SEC5_q3_4_`var', SEC5_q3_5_`var', SEC5_q3_6_`var', ///
			SEC5_q3_7_`var', SEC5_q3_8_`var') ///
		& !inlist(8, SEC5_q3_1_`var', SEC5_q3_2_`var', SEC5_q3_3_`var', ///
			SEC5_q3_4_`var', SEC5_q3_5_`var', SEC5_q3_6_`var', ///
			SEC5_q3_7_`var', SEC5_q3_8_`var') ///
		if !mi(SEC5_q2_`var')
}
	
gen connect_pgp = inlist(1,connect_political,connect_officer,connect_police_army)

la var connect_political "Connected to Politician"
la var connect_officer "Connected to Gov't officer"
la var connect_police_army "Connected to Police/Army"
la var connect_pgp "Connected to Politician/Government/Police"


** DUMMIES FOR SOCIAL NETWORKS
forv i = 1/2{
	local a: word `i' of "hh" "close"
	forv j = 1/4{
		local b: word `j' of "political" "officer" "police_army" "med_lawyer"
		gen `a'_`b' = SEC5_q`i'_`b' == 1 if SEC5_q`i'_`b' != .
		la var `a'_`b' "Member of `a' is `b'"
		}
	}

saveold "Data/Cleaned Data/Field Survey/Round 3/Cleaned/Section 5.dta", replace

	
******************************************
* Section 6

u "Data/Cleaned Data/Field Survey/Round 3/Compiled/Section 6.dta", clear
cleanmissings

foreach var of varlist  SEC6_q3 SEC6_q5 {
	replace `var' = . if `var' == 999
	replace `var' = . if `var' == 99 // don't know
	}
	
** PER-CAPITA EXPENDITURE
gen expenditure = SEC6_q3 / SEC6_q1
la var expenditure "Per-capita expenditure"

** PER-CAPITA WAGES
gen wages = SEC6_q3 / SEC6_q2
la var wages "Per-capita wages"

** CLEANUP FOR CONSUMPTION GOODS
** Binary for "Has [LCD/CRT] TV"
gen SEC6_q7_lcd = SEC6_q7_f == 1 if short_section6 != 1
gen SEC6_q7_crt = SEC6_q7_f == 2 if short_section6 != 1
** Number of Cars can be zero
replace SEC6_q7_j = 0 if SEC6_q7_j == . & short_section6 != 1

** RENTAL VALUE
gen rental_value = SEC6_q5
replace rental_value = SEC6_q6 if rental_value == .

** PREDICTED VALUES OF WAGES AND EXPENDITURE BASED ON HH ASSETS
foreach var of varlist SEC6_q7*{
	gen `var'_dummy = `var' == 1 if `var' != .
	}
drop SEC6_q7_f_dummy SEC6_q7_j_dummy // these aren't proper binary dummies.
reg expenditure *_dummy SEC6_q7_j
predict expenditure_hat
la var expenditure_hat "Predicted values of expenditure given assets owned"
reg wages *_dummy
predict wages_hat
la var wages_hat "Predicted values of wages given assets owned"
	
saveold "Data/Cleaned Data/Field Survey/Round 3/Cleaned/Section 6.dta", replace

******************************************
* Section 7

u "Data/Cleaned Data/Field Survey/Round 3/Compiled/Section 7.dta", clear
cleanmissings

** MAIN ROAD
g main_road = SEC7_q1==1 | SEC7_q1b==1
replace main_road = . if SEC7_q1 == . & SEC7_q1b == .

** DUMMY FOR OWNER-OCCUPIED
gen owner_occupied = (SEC7_q5 == 1 | SEC7_q5 == 3) if SEC7_q5 != .
la var owner_occupied "Property is owned by occupant"

* RENAME LAND/COVERED AREA
ren SEC7_q7b_area open_area
ren SEC7_q7b_unit open_area_un
ren SEC7_q7b_type open_area_typ
renpfix SEC7_q6a land
ren land_unit land_area_un
renpfix SEC7_q7a cov
renpfix cov_unit_ cov_area_un
renpfix cov_type_ cov_area_typ
ren cov_area_? cov_area?
renpfix SEC7_q7b gr_cov
renpfix gr_cov_unit_ gr_cov_area_un
renpfix gr_cov_type_ gr_cov_area_typ
ren gr_cov_area_? gr_cov_area?
ren SEC7_q7c_1 floors
ren SEC7_q7c_2 basement
ren SEC7_q7c_3 splitlevel
ren SEC7_q5 owned

* CLEAN LAND AREA USE
replace land_area_un = 5 if inlist(prop_id,"0303301010015","02051000701","03071000508","0700100030004","03020001208","0303301010010","0307400010005")
replace land_area_un = 2 if inlist(prop_id,"0902200010024","05063000701","0909800020003","0909500010059","01081010408","0909800030004")
replace land_area_un = 2 if inlist(prop_id,"0909800030011","0909800030009","01071000306","01081010305","0307200010001","03087001006")
replace land_area_un = 2 if inlist(prop_id,"0108101030001","0108102030001","02001010306","0307500020012","0108102020027","0107800020005")
replace cov_area_un1 = 5 if inlist(prop_id,"0900500020002","07014000307","07001000308")
replace cov_area_un2 = 5 if inlist(prop_id,"09013000403")
replace cov_area1 = 3500 if prop_id=="06122100806"
replace cov_area1 = 2375 if prop_id=="05066000209"


saveold "Data/Cleaned Data/Field Survey/Round 3/Cleaned/Section 7.dta", replace

******************************************
* Section 8

u "Data/Cleaned Data/Field Survey/Round 3/Compiled/Section 8.dta", clear
cleanmissings
saveold "Data/Cleaned Data/Field Survey/Round 3/Cleaned/Section 8.dta", replace


******************************************
* Title

u "Data/Cleaned Data/Field Survey/Round 3/Compiled/Title.dta", clear
cleanmissings

** CHANGE JUNE 31 TO JULY 1
gen dateflag = 1 if T_q7_int_month == 6 & T_q7_int_day == 31
replace T_q7_int_month = 7 if dateflag == 1
replace T_q7_int_day = 1 if dateflag == 1
drop dateflag
gen surveydate = mdy(T_q7_int_month,T_q7_int_day,T_q7_int_y + 2000)
format surveydate %td

saveold "Data/Cleaned Data/Field Survey/Round 3/Cleaned/Title.dta", replace


********************************************************************************************************
********************************************************************************************************
********************************************************************************************************


** MERGE ALL SECTIONS TOGETHER *************************************************
u "Data/Cleaned Data/Field Survey/Round 3/Cleaned/Log_Sec1.dta", clear
duplicates drop circle_id cluster_id, force
gen SEC9 = 0
tempfile log_sec1
save `log_sec1'

use "Data/Cleaned Data/Field Survey/Round 3/Cleaned/Title.dta", clear
gen SEC9 = 0
append using "Data/Cleaned Data/Field Survey/Round 3/Cleaned/Sec9_Title.dta"
isid prop_id
tempfile title
sa `title'

use "Data/Cleaned Data/Field Survey/Round 3/Cleaned/Log_Sec2.dta", clear
gen SEC9 = 0
append using "Data/Cleaned Data/Field Survey/Round 3/Cleaned/Sec9_Log.dta"
isid prop_id

gen source = ""

merge m:1 prop_id using `title', gen(_mtitle) update
	replace source = "long" if long_title == 1
	replace source = "short" if source == "" & short_title == 1
	replace source = "SEC9_survey" if inlist(_mtitle, 3, 4) & source == "" & SEC9 == 1

	replace source = "address_only" if source == "" & _mtitle == 1 & SEC9 != 1 & LS2_q13 == 1
	replace source = "non_response" if source == "" & _mtitle == 1 & SEC9 != 1 & LS2_q13 != 1

	replace source = "SEC9_address_only" if source == "" & _mtitle == 1 & SEC9 == 1
	replace source = "SEC9_title_only" if source == "" & _mtitle == 2 & SEC9 == 1
	replace source = "title_only" if source == "" & _mtitle == 2 & SEC9 != 1
	
merge 1:1 prop_id using "Data/Cleaned Data/Field Survey/Round 3/Cleaned/Backmatch.dta", gen(_mBM) update
	replace source = "BM_only" if _mBM == 2
	replace SEC9 = 0 if missing(SEC9)

forv x = 1/8{
	* cfvlabs "Original Data/Survey Round 3/Compiled/Section `x'.dta"
	merge 1:1 prop_id using "Data/Cleaned Data/Field Survey/Round 3/Cleaned/Section `x'.dta", ///
		gen(_m`x') update
		assert _m`x' != 2
	replace source = "section_`x'_only" if source == "" & _m`x' == 2
	}
	merge m:1 cluster_id circle_id using `log_sec1', gen(_mlogsec1) update
keep if _mlogsec1 != 2 // because we only want property-level observations.

ta source SEC9, mis
gen enum = !missing(enum_code)
ta source enum, mis

gen phase2 = phase == 2
replace phase2 = . if missing(phase)


** LAND AREA
/* From Obeid's email dated 20 Sept 2013
	The marla measurements will be consistent at the circle level. So we can use
	the marla units from the non-section 9 data for each respective circle. 

	From the non-section 9 data there are only 4 circles where marla measurement
	varied within the circle, for these we can go with the following rule of thumb.
	225 sqft for Lahore A & B Circles and 272.25sqft for non Lahore circles.

*WAS 131003: I actually don't even find any circles where marla measurement
varies, but the assertion below will catch them if they ever show up somehow.
*/

preserve
	u "Data/Cleaned Data/Field Survey/Round 3/Cleaned/Log_Sec1.dta", clear
	keep circle_id LS1_q8
	drop if LS1_q8 == .   // These are missing because surveyors did not find properties in that cluster
	ren LS1_q8 marla_def
	duplicates drop
	isid circle_id
	tempfile marla_defs
	save `marla_defs'
restore

merge m:1 circle_id using `marla_defs'
assert _merge == 3
drop _merge

/* WAS: if this assertion is false, there are
	inconsistent marla definitions within some circle(s), and they need to be
	dealt with as Obeid outlines above */
	
********************************************************************************************************
********************************************************************************************************
********************************************************************************************************

* Variables that need to be calculated after the merge

gen yrs_occupy = floor(year(surveydate) - SEC4_q1) if !mi(SEC4_q1)
la var yrs_occupy "How many years have you been an occupant of this property?"

** STANDARDIZE AREAS
foreach a in land open BM_land {
	*assert `a'_area_un != . if `a'_area != . & `a'_area != 0
	gen temp = `a'_area
	replace temp = `a'_area * 9 if `a'_area_un == 2 						// "SQYD"
	replace temp = `a'_area * 43560 if `a'_area_un == 3 					// "ACRE"
	replace temp = `a'_area * 4500 if `a'_area_un == 4  & marla_def == 1	// "KANAL"
	replace temp = `a'_area * 5445 if `a'_area_un == 4  & marla_def == 2	// "KANAL"
	replace temp = `a'_area * 225 if `a'_area_un == 5 & marla_def == 1		// "MARLA"
	replace temp = `a'_area * 272.25 if `a'_area_un == 5 & marla_def == 2 	// "MARLA"
	replace `a'_area = temp / 9  // We need to convert from square feet to square yards
	drop temp 
	}
	
gen sft_land_area = land_area * 9

* COVERED AREA / GROUND COVERED AREA
forval i = 1/5 {
	foreach a in cov gr_cov BM_cov {
			di "`i' `a'"
			cap confirm variable `a'_area`i'
			if _rc {
				di "Does not exist"
			}
			else {
				// Consistency check: always have use type and units
				if "`a'" != "BM_cov" assert `a'_area_un`i'!=. if `a'_area_typ`i' !=. & `a'_area`i'!= 0
				**KM 131014: THIS ASSERTION ONLY BREAKS FOR BACKMATCHING
				list prop_id `a'_area_un`i' `a'_area_typ`i' `a'_area`i' ///
					if `a'_area`i' != . & ///
					(`a'_area_un`i' == . | `a'_area_typ`i' == .)
				replace `a'_area`i' = `a'_area`i'*9 if `a'_area_un`i'==2 						// "SQ YD"
				replace `a'_area`i' = `a'_area`i'*43560 if `a'_area_un`i'==3 					// "ACRE"
				replace `a'_area`i' = `a'_area`i'*4500 if `a'_area_un`i'==4 & marla_def==1		// "KANAL"
				replace `a'_area`i' = `a'_area`i'*5445 if `a'_area_un`i'==4 & marla_def==2		// "KANAL"
				replace `a'_area`i' = `a'_area`i'*225 if `a'_area_un`i'==5 & marla_def==1		// "MARLA"
				replace `a'_area`i' = `a'_area`i'*272.25 if `a'_area_un`i'==5 & marla_def==2 	// "MARLA"
			}
		}
	}

* TOTAL AREAS
egen tot_cov_area = rowtotal(cov_area?)
replace tot_cov_area = . if tot_cov_area == 0

egen tot_gr_cov_area = rowtotal(gr_cov_area?)
replace tot_gr_cov_area = . if tot_gr_cov_area == 0

egen BM_tot_cov_area = rowtotal(BM_cov_area?)
replace BM_tot_cov_area = . if BM_cov_area1 == . & BM_cov_area2 == . & BM_cov_area3 == .

saveold "Data/Cleaned Data/Field Survey/Round 3/survey_cleaned_data_with_address_only.dta", replace
keep if inlist(source,"long","short","SEC9_survey")
saveold "Data/Cleaned Data/Field Survey/Round 3/survey_cleaned_data.dta", replace

********************************************************************************************************
********************************************************************************************************
********************************************************************************************************

* Additional variables for the non-address only properties
* ---------------------------------------------------------

** GENERATE GARV AND TAX LIABLITY
do "Data/Do Files/Cleaning/Survey Data/Round 3/TaxLiabilityCalc.do"

** GENERATE GARV AND TAX LIABILITY FOR PROPERTIES WITH MISSING CATEGORY
do "Data/Do Files/Cleaning/Survey Data/Round 3/Impute Tax - Corrected.do"


use "Data/Cleaned Data/Field Survey/Round 3/survey_cleaned_data.dta", clear

merge 1:1 prop_id using "Data/Cleaned Data/Field Survey/Round 3/TaxLiabilityCalc.dta", gen(_mTaxCalc) update
assert _mTaxCalc != 2 // there should be no backmatching of props not in survey


merge 1:1 prop_id using "Data/Cleaned Data/Field Survey/Round 3/Imputed Tax.dta", update
replace imputed = 0 if _merge == 1
assert _merge != 2
drop _merge

** Percent differences and absolute value percent differences
foreach a in GARV tax_liability {
** Raw differences
	g diffraw_`a' = (BM_`a' - `a')
** Pct differences
	g diff_pct_`a' = diffraw_`a' / (`a' + BM_`a')
	replace diff_pct_`a' = 0 if `a' == 0 & BM_`a' == 0
	la var diff_pct_`a' "Pct difference in `: var l `a''"
** Absolute value percent differences
	gen diff_`a' = abs(diff_pct_`a')
	la var diff_`a' "Absolute value pct difference in `: var l `a''"
}

cap label drop category
cap label define category 1 "G" 2 "F" 3 "E" 4 "D" 5 "C" 6 "B" 7 "A"
cap label values category_scale category

saveold "Data/Cleaned Data/Field Survey/Round 3/survey_cleaned_data.dta", replace

